Qt.include("changeStatus.js");
Qt.include("Utility.js");
//
// raggio del radar recuperato dal backend C++
var radius;
var showEnemyOnMap = bridge.showEnemyInMap();
var isOwner = bridge.isMapOwner();
var fallbackPage = getFallbackPage(isOwner);
var rootRadioVoices = bridge.getRadioVoicePath();
//
// inviata dal proprietario quando vuole terminare il gioco in corso:
function stopGamePlay() {
    bridge.changeMapStatusCompleted.connect(resultOfClosingGameRequest); // si aggancia al completamento del cambio stato per la mappa
    bridge.changeStatusMap(getMapStatus(SWITCH_MAP_STATUS_TO_END)); // cambio lo stato della mappa in gioco
}
//
// notifica terminazione gioco, emessa dai server embedded:
function killGameRequestNotify(status) {
    if (status === getMapStatus(SWITCH_MAP_STATUS_TO_END)) {
        lcdPanel.setInfoSystem(false, qsTr("Gioco terminato dal proprietario"));
        goToFallbackPage();
    }
}
//
// ricevuta come risposta dalla richiesta di chiusura gioco
function resultOfClosingGameRequest(result, msg) {
    if (result === true) { // ok: richiama chiusura gioco per il proprietario
        try {
            lcdPanel.setInfoSystem(false, qsTr("Chiusura gioco accettata ed in corso..."));
            goToFallbackPage();
        }
        catch (ex) {
            ; // nessuna operazione significativa
        }
    }
    else {
        if (isOwner === false)
           msg = qsTr("Impossibile chiudere la partita in corso");
        else
           msg = qsTr("Problemi nella chiusura della partita");
        try {
            if (lcdPanel !== 0) lcdPanel.setInfoSystem(true, msg);
        }
        catch (ex) {
            ; // nessuna operazione significativa
        }
        btnTerminate.resetClickStatus = true;
        btnTerminate.enabled = true;
    }
}

function goToFallbackPage() {
    pageStack.replace(Qt.resolvedUrl(fallbackPage));
}

function resultOfKilling(result, msg) {
    if (result === true) {
        lcdPanel.setInfoSystem(false, qsTr("Eliminazione avvenuta con successo"));
    }
    else {
        lcdPanel.setInfoSystem(true, qsTr("Eliminazione non riuscita: riprovare in seguito"));
        btnKilled.enabled = true;
        btnKilled.resetClickStatus = true;
    }
}
//
// avviata quando si apre la lista dei messaggi da inviare verso i players
function openMessageList(idObject, isPOI) {
    listMessage.idObject = idObject;
    listMessage.isPOI = isPOI;
    bridge.populateMessageList(isPOI, false);
    listMessage.visible = true;
}

//
// emesso quando c'e' la presenza di qualche nemico nelle vicinanze
function enemySpottedAlert() {
    radioVoiceSound.play(rootRadioVoices, "enemySpotted.wav", false);
    lcdPanel.setInfoMessage(true, qsTr("ATTENZIONE: presenza di nemici nelle vicinanze!"));
}
//
// emesso quando c'e' un target da raggiungere e ci si trova nelle vicinanze
function targetAcquiredAlert() {
    radioVoiceSound.play(rootRadioVoices, "targetAcquired.wav", false);
    lcdPanel.setInfoMessage(false, qsTr("obiettivo della missione in avvicinamento"));
}
//
// informazioni sul numero di giocatori: il player corrente sara' sempre un mate
var alerted = false;

function infoAboutNumberPlayer(totMate, totEnemy) {
    var noTeamEnemy = !(bridge.teamEnemyInGame()); // indica il numero di nemici ad avvio partita (per indicare se ci sono nemici che partecipano)

    lcdPanel.totalEnemy = totEnemy;
    lcdPanel.totalMate = totMate;
    if (alerted == false && noTeamEnemy == false && totEnemy === 0) { // per i players che sconfiggono i nemici
        alerted = true;
        radioVoiceSound.play(rootRadioVoices, "completed.wav", false);
        lcdPanel.setInfoMessage(true, qsTr("MISSIONE COMPLETATA"));
    }
}

function playerKilledNotification(nickname, isFellow, id) {
    var soundName = "";

    if (isFellow) {
        lcdPanel.setInfoMessage(true, nickname + qsTr(" e' stato eliminato dai nemici"));
        rumbleEffect.killRumble();
    }
    else {
        lcdPanel.setInfoMessage(true, qsTr("Nemico ") + nickname + qsTr(" eliminato dalle tue truppe"));
        soundName = "enemyDown.wav";
    }
    radioVoiceSound.play(rootRadioVoices, soundName, false);
}
//
// lanciato quando un player ha inviato richiesta di aiuto per attacco nemico
function playerUnderAttack(nickname) {
    lcdPanel.setInfoMessage(true, qsTr("ATTENZIONE: ") + nickname + qsTr(" e' sotto attacco!"));
    radioVoiceSound.play(rootRadioVoices, "mayDay.wav", false);
    rumbleEffect.targetRumble();
}

//
// quando arriva un nuovo messaggio inviato dal comandante
function communicationMsg(msg, audio, isCustom) {
    lcdPanel.setInfoMessage(false, msg);
    littleNavigator.commanderMessage = msg;
    if (isCustom === false)
        radioVoiceSound.play(rootRadioVoices, audio, false);
    else
        radioVoiceSound.play(rootRadioVoices, audio, false);
    rumbleEffect.targetRumble();
}
//
// quando arriva un nuovo target inviato dal comandante
function communicationPOI(msg, audio, isCustom) {
    lcdPanel.setInfoMessage(false, qsTr("Nuovo target comunicato dal tuo comandante"));
    littleNavigator.commanderMessage = msg;
    if (isCustom === false)
        radioVoiceSound.play(rootRadioVoices, audio, true);
    else
        radioVoiceSound.play(rootRadioVoices, audio, true); // TODO: memorizzare tutto il percorso del file; occhio alla dimensione della struttura TMessagePOI
    rumbleEffect.targetRumble();
}
//
// se il player e' comandante, all'invio di un nuovo target ricevera' messaggio di esito
function respondToPOICommand(msg) {
    rumbleEffect.killRumble();
    lcdPanel.setInfoMessage(false, msg);
}

//
// livello settato dal backend C++ (circles indica il numero di cerchi da disegnare, visibility e' lo scope in metri
function zoomLevelSet(circles, visibility) {
    drawZoomCircle(circles); // disegna i cerchi in base alle info ricevute
    // TODO: aggiorna la UI con il tipo di zoom applicato e la visibilita' in metri
}

function cleanCircle() {
    for (var i = 0; i < zoomLevelContainer.children.length; i++)
        zoomLevelContainer.children[i].destroy();
}

function drawZoomCircle(circles) {
    var	step = radius / (circles + 1);
    var	incrementStep = 2;
    var	newCircle;

    cleanCircle();
    for (var i = 1; i <= circles; i++) {
        newCircle = Qt.createQmlObject("import QtQuick 1.0; Rectangle { border.color: 'green';color: '#00000000';}", zoomLevelContainer);
        newCircle.anchors.horizontalCenter = zoomLevelContainer.horizontalCenter;
        newCircle.anchors.verticalCenter = zoomLevelContainer.verticalCenter;
        newCircle.width = step * incrementStep;
        newCircle.height = newCircle.width;
        newCircle.radius = newCircle.width * 0.5;
        newCircle.x = zoomLevelContainer.width / 2 - (step * i);
        newCircle.y = zoomLevelContainer.height / 2 - (step * i);
        incrementStep += 2;
    }
}

