// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.symbian 1.1
import "../../../js/Navigator.js" as JNavigator
import "../"

Rectangle {
    id: container
    width: 360
    height: 148
    color: "#00000000"

    Component.onCompleted: bridge.clearInfoEmbeddedNav.connect(clearTargetNav)
    Component.onDestruction: bridge.clearInfoEmbeddedNav.disconnect(clearTargetNav)

    property alias nicknameCommander: objectCommanderName.text;
    property bool  openPanel: false
    property alias posX: point.x
    property alias posY: point.y
    property alias description: objectName.text
    property alias distance: distance.text
    property alias thumbnail: thumb.source
    property alias commanderMessage: objectCommanderMsg.text
    property alias miniRadarPointVisible: point.visible

    onOpenPanelChanged: {
        if (openPanel == true)
            cover.y = swipeCloser.drag.maximumY;
        else
            cover.y = swipeCloser.drag.minimumY;
    }

    function clearTargetNav() {
        objectName.text = "";
        distance.text = "";
        objectCommanderMsg.text = "";
        thumb.source = "";
    }

    Rectangle {
        id: consollePanel
        x: 0
        y: 0
        color: "#00000000"
        clip: true
        anchors.fill: parent
        anchors.rightMargin: 0
        anchors.bottomMargin: 0
        anchors.leftMargin: 0
        anchors.topMargin: 0

        Image {
            id: cover
            y: 0
            x: 0
            z: 100
            anchors.right: parent.right
            anchors.rightMargin: 0
            anchors.left: parent.left
            anchors.leftMargin: 0
            height: consollePanel.height
            fillMode: Image.PreserveAspectFit
            source: "qrc:/images/" + bridge.getDeviceResolution() + "/cover.png"
            width: consollePanel.width

            MouseArea {
                id: swipeCloser
                width: 100
                height: 50
                anchors.horizontalCenter: parent.horizontalCenter
                drag.target: cover
                drag.axis: Drag.YAxis
                drag.minimumY: 0
                drag.maximumY: cover.height - 43
                hoverEnabled: true
                anchors { top: parent.top; topMargin: 0 }
                onReleased: {
                    if (cover.y > drag.maximumY / 2)
                        cover.y = drag.maximumY;
                    else
                        cover.y = drag.minimumY;
                }
            }

            Behavior on y {
                NumberAnimation { duration: 200 }
            }

            SwitchButton {
                id: btnMsgToAll
                width: 36
                height: 80
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                anchors.left: btnZoom.right
                anchors.leftMargin: 5
                foregroundImageWidth: 20
                foregroundImageHeight: 25
                foregroundImage: "qrc:/images/" + bridge.getDeviceResolution() + "/button_ico_msg.png"
                backgroundOff: "qrc:/images/" + bridge.getDeviceResolution() + "/button_off.jpg"
                backgroundOn: "qrc:/images/" + bridge.getDeviceResolution() + "/button_on.jpg"
                onClickButton: bridge.openMessageList(0, false);

                Component.onCompleted: btnMsgToAll.enabled = bridge.isCommander()
            }

            SwitchButton {
                id: btnSOS
                width: 36
                height: 80
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                pressAndHoldBehavior: true
                foregroundImageWidth: 20
                foregroundImageHeight: 16
                foregroundImage: "qrc:/images/" + bridge.getDeviceResolution() + "/button_ico_help.png"
                backgroundOff: "qrc:/images/" + bridge.getDeviceResolution() + "/button_off.jpg"
                backgroundOn: "qrc:/images/" + bridge.getDeviceResolution() + "/button_on.jpg"

                onPressAndHoldButton: {
                    btnSOS.enabled = false;
                    rumbleEffect.killRumble();
                    bridge.sendSOS();
                    stopUnderAttack.start();
                }

                Timer {
                    id: stopUnderAttack
                    interval: bridge.getSOSMillisecondTime()
                    repeat: false
                    onTriggered: {
                        btnSOS.enabled = true;
                        btnSOS.resetClickStatus = true;
                    }
                }
            }

            SwitchButton {
                id: btnRadioVoiceSound
                width: 36
                height: 80
                anchors.right: btnKilled.left
                anchors.rightMargin: 5
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                pressAndHoldBehavior: true
                foregroundImageWidth: 21
                foregroundImageHeight: 18
                foregroundImage: "qrc:/images/" + bridge.getDeviceResolution() + "/button_ico_audio.png"
                backgroundOff: "qrc:/images/" + bridge.getDeviceResolution() + "/button_off.jpg"
                backgroundOn: "qrc:/images/" + bridge.getDeviceResolution() + "/button_on.jpg"

                property bool muted: false

                Component.onCompleted: radioVoiceSound.muted = muted

                onPressAndHoldButton: {
                    rumbleEffect.killRumble();
                    radioVoiceSound.muted = btnRadioVoiceSound.muted = !btnRadioVoiceSound.muted;
                }
            }

            SwitchButton {
                id: btnZoom
                width: 36
                height: 80
                anchors.left: btnSOS.right
                anchors.leftMargin: 5
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                foregroundImageWidth: 20
                foregroundImageHeight: 18
                foregroundImage: "qrc:/images/" + bridge.getDeviceResolution() + "/button_ico_zoom.png"
                backgroundOff: "qrc:/images/" + bridge.getDeviceResolution() + "/button_off.jpg"
                backgroundOn: "qrc:/images/" + bridge.getDeviceResolution() + "/button_on.jpg"

                onClickButton: {
                    rumbleEffect.killRumble();
                    bridge.nextZoomLevel();
                }
            }

            SwitchButton {
                id: btnTerminate
                width: 36
                height: 80
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                pressAndHoldBehavior: true
                foregroundImageWidth: 20
                foregroundImageHeight: 20
                foregroundImage: "qrc:/images/" + bridge.getDeviceResolution() + "/button_ico_exit.png"
                backgroundOff: "qrc:/images/" + bridge.getDeviceResolution() + "/button_off.jpg"
                backgroundOn: "qrc:/images/" + bridge.getDeviceResolution() + "/button_on.jpg"

                onPressAndHoldButton: {
                    rumbleEffect.killRumble();
                    btnTerminate.enabled = false;
                    lcdPanel.setInfoSystem(false, qsTr("Richiesta di chiusura mappa in corso..."));
                    JNavigator.stopGamePlay();
                }
            }

            SwitchButton {
                id: btnKilled
                width: 36
                height: 80
                anchors.right: btnTerminate.left
                anchors.rightMargin: 5
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                pressAndHoldBehavior: true
                foregroundImageWidth: 17
                foregroundImageHeight: 29
                foregroundImage: "qrc:/images/" + bridge.getDeviceResolution() + "/button_ico_death.png"
                backgroundOff: "qrc:/images/" + bridge.getDeviceResolution() + "/button_off.jpg"
                backgroundOn: "qrc:/images/" + bridge.getDeviceResolution() + "/button_on.jpg"

                onPressAndHoldButton: {
                    // TODO: in caso di commander, individuare il nuovo commander
                    rumbleEffect.killRumble();
                    btnKilled.enabled = false;
                    lcdPanel.setInfoSystem(false, qsTr("Richiesta di eliminazione dalla mappa in corso..."));
                    bridge.killMe();
                }
                Component.onCompleted: bridge.killMeCompleted.connect(JNavigator.resultOfKilling);
                Component.onDestruction: bridge.killMeCompleted.disconnect(JNavigator.resultOfKilling);
            }

            Compass {
                id: compass
                compassWidth: 70
                compassHeight: 70
                color: "#00000000"
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 14

                Component.onCompleted: bridge.newCompassAngle.connect(compass.refreshCompass);
                Component.onDestruction: bridge.newCompassAngle.disconnect(compass.refreshCompass);
            }
        }

        Rectangle {
            id: consolle
            height: imgBackPanel.height
            color: "#00000000"
            radius: 8
            anchors.right: parent.right
            anchors.rightMargin: 16
            anchors.left: parent.left
            anchors.leftMargin: 16
            clip: false
            anchors.top: parent.top
            anchors.topMargin: 32

            Image {
                id: imgBackPanel
                width: 274
                height: 81
                fillMode: Image.PreserveAspectFit
                source: "qrc:/images/" + bridge.getDeviceResolution() + "/panel.jpg"
            }

            Text {
                id: objectName
                x: 40
                y: 78
                height: 15
                color: "#87C503"
                verticalAlignment: Text.AlignVCenter
                font.family: "Courier New"
                font.bold: true
                anchors.right: containerMiniRadar.left
                anchors.rightMargin: 10
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.left: labelObjectName.right
                anchors.leftMargin: 0
                font.pixelSize: 12
            }

            Rectangle {
                id: containerMiniRadar
                x: 7
                width: 50
                height: 48
                color: "#00000000"
                anchors.right: parent.right
                anchors.rightMargin: 0
                anchors.top: parent.top
                anchors.topMargin: 0

                Image {
                    id: miniRadar
                    anchors.fill: parent
                    fillMode: Image.PreserveAspectFit
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.verticalCenter: parent.verticalCenter
                    source: "qrc:/images/" + bridge.getDeviceResolution() + "/miniradar.png"

                    Image {
                        id: point
                        x: 0
                        y: 0
                        width: 7
                        height: 7
                        visible: false
                        fillMode: Image.PreserveAspectFit
                        source: "qrc:/images/mini_radar_point.png"
                    }
                }
            }

            Text {
                id: distance
                x: 333
                height: 15
                color: "#FFFFFF"
                clip: true
                font.italic: false
                font.pixelSize: 10
                anchors.top: labelObjectName.bottom
                anchors.topMargin: 1
                anchors.rightMargin: 6
                anchors.right: containerMiniRadar.left
                anchors.leftMargin: 35
                anchors.left: parent.left
            }

            Image {
                id: thumb
                width: 19
                height: 19
                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.top: parent.top
                anchors.topMargin: 6
                fillMode: Image.PreserveAspectFit
            }

            Text {
                id: labelObjectName
                x: 60
                y: 7
                width: 97
                height: 15
                color: "#ffffff"
                text: qsTr("Nome oggetto:")
                verticalAlignment: Text.AlignVCenter
                font.family: "Courier New"
                font.pixelSize: 12
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.leftMargin: 35
                anchors.left: parent.left
            }

            Text {
                id: labelCommander
                x: 51
                y: 5
                width: 72
                height: 15
                color: "#ffffff"
                text: qsTr("Comandante:")
                font.bold: true
                font.family: "Courier New"
                font.pixelSize: 12
                anchors.top: thumb.bottom
                anchors.topMargin: 10
                anchors.leftMargin: 5
                anchors.left: parent.left
            }

            Text {
                id: objectCommanderName
                x: 46
                y: 74
                height: 15
                color: "#FAF567"
                text: "AlterX"
                font.family: "Courier New"
                font.bold: true
                font.pixelSize: 12
                anchors.top: thumb.bottom
                anchors.topMargin: 10
                anchors.rightMargin: 15
                anchors.right: containerMiniRadar.left
                anchors.leftMargin: 10
                anchors.left: labelCommander.right
            }

            Text {
                id: objectCommanderMsg
                x: 326
                y: 82
                color: "#87C503"
                font.bold: false
                horizontalAlignment: Text.AlignLeft
                font.family: "Courier New"
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                font.italic: false
                font.pixelSize: 9
                anchors.top: labelCommander.bottom
                anchors.topMargin: 3
                anchors.rightMargin: 6
                anchors.right: containerMiniRadar.left
                anchors.leftMargin: 5
                anchors.left: parent.left
            }

            SwitchButton {
                id: imgZoom
                width: 25
                height: 32
                color: "transparent"
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 0
                anchors.right: imgNoTarget.left
                anchors.rightMargin: 0
                backgroundOff: "qrc:/images/" + bridge.getDeviceResolution() + "/zoom.png"
                backgroundOn: "qrc:/images/" + bridge.getDeviceResolution() + "/zoom.png"

                onClickButton: {
                    if (openPanel == true) {
                        rumbleEffect.killRumble();
                        bridge.nextZoomLevel();
                    }
                }
            }

            SwitchButton {
                id: imgNoTarget
                width: 25
                height: 32
                color: "transparent"
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 0
                anchors.right: parent.right
                anchors.rightMargin: 0
                pressAndHoldBehavior: true
                backgroundOff: "qrc:/images/" + bridge.getDeviceResolution() + "/erasePOI.png"
                backgroundOn: "qrc:/images/" + bridge.getDeviceResolution() + "/erasePOI.png"

                Component.onCompleted: bridge.activeNoTargetButton.connect(hideButton);
                Component.onDestruction: bridge.activeNoTargetButton.disconnect(hideButton);

                function hideButton(visible) {
                    imgNoTarget.enabled = visible;
                }

                onPressAndHoldButton: {
                    if (bridge.isCommander()) {
                        rumbleEffect.targetRumble();
                        bridge.setNewTarget(0, 0, true);
                        clearTargetNav();
                    }
                }
            }
        }
    }
}
