// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.symbian 1.1
import QtMultimediaKit 1.1
import QtMobility.feedback 1.1
import "../../../js/Navigator.js" as JNavigator
import "../../../js/Utility.js" as JUtility
import "../" // il file si trova in una directory diversa dagli altri oggetti, quindi importa la precedente radice


Page {
    id:navigatorGame
    orientationLock: PageOrientation.LockPortrait

    Component.onCompleted: {
        JNavigator.radius = bridge.getRadarRadius();
        bridge.communicationMsg.connect(JNavigator.communicationMsg);
        bridge.communicationPOI.connect(JNavigator.communicationPOI);
        bridge.respondToPOICommand.connect(JNavigator.respondToPOICommand);
        bridge.playerUnderAttack.connect(JNavigator.playerUnderAttack);
        bridge.playerKilled.connect(JNavigator.playerKilledNotification);
        bridge.updateNewStatusMap.connect(JNavigator.killGameRequestNotify); // per il proprietario non verra' mai lanciato il segnale
        bridge.commanderNotification.connect(setNicknameCommander); // deve precedere la chiamata a preparePlayers()
        bridge.infoAboutNumberPlayer.connect(JNavigator.infoAboutNumberPlayer); // deve precedere la chiamata a preparePlayers()
        bridge.preparePOIs(imgBackground, littleNavigator, bridge.preparePlayers(imgBackground));
        bridge.newZoomLevelSet.connect(JNavigator.zoomLevelSet);
        bridge.enemySpottedAlert.connect(JNavigator.enemySpottedAlert);
        bridge.targetAcquiredAlert.connect(JNavigator.targetAcquiredAlert);
        bridge.openMessageListNotify.connect(JNavigator.openMessageList);
        bridge.startNavigator();
    }

    Component.onDestruction: {
        bridge.updateNewStatusMap.disconnect(JNavigator.killGameRequestNotify);
        bridge.playerUnderAttack.disconnect(JNavigator.playerUnderAttack);
        bridge.playerKilled.disconnect(JNavigator.playerKilledNotification);
        bridge.commanderNotification.disconnect(setNicknameCommander);
        bridge.communicationMsg.connect(JNavigator.communicationMsg);
        bridge.communicationPOI.disconnect(JNavigator.communicationPOI);
        bridge.respondToPOICommand.disconnect(JNavigator.respondToPOICommand);
        bridge.enemySpottedAlert.connect(JNavigator.enemySpottedAlert);
        bridge.targetAcquiredAlert.disconnect(JNavigator.targetAcquiredAlert);
        bridge.openMessageListNotify.disconnect(JNavigator.openMessageList);
        bridge.infoAboutNumberPlayer.disconnect(JNavigator.infoAboutNumberPlayer);
        bridge.stopNavigator();
    }

    function setNicknameCommander(nick, playerName, isCommander) {
        littleNavigator.nicknameCommander = nick;
        lcdPanel.name = playerName;
        lcdPanel.isCommander = isCommander;
    }

    RadioVoiceControl {
        id: radioVoiceSound
    }

    SoundEffect {
        id: alertSound
        source: "../../../audio/popup.wav"
    }

    MessageListView {
        id: listMessage
        z: 50
        width: 320
        height: 450
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
    }

    HapticsEffect {
        id: rumbleEffect
        attackIntensity: 0.5
        attackTime: 50
        intensity: 0.5
        duration: 250 // set up the duration here, in millisecond
        fadeTime: 50
        fadeIntensity: 0.0

        function killRumble() {
            rumbleEffect.duration = 250;
            rumbleEffect.start();
        }

        function targetRumble() {
            rumbleEffect.duration = 500;
            rumbleEffect.start();
        }
    }

    Image {
        id: imgBackground
        clip: true
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        Component.onCompleted: source = "qrc:/images/" + bridge.getDeviceResolution() + "/radar.png"

        LedPanel {
            id: lcdPanel
            width: 293
            height: 93
            anchors.left: parent.left
            anchors.leftMargin: 33
            anchors.top: parent.top
            anchors.topMargin: 38

            Component.onCompleted: setInfoSystem(false, qsTr("Gioco sulla mappa avviato con successo!"))
        }

        EmbeddedNavigator {
            id: littleNavigator
            width: 360
            height: 148
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 0
        }

        Rectangle {
            id: zoomLevelContainer
            z: 1
            color: "#00000000"
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 152
            anchors.right: parent.right
            anchors.rightMargin: 8
            anchors.top: parent.top
            anchors.topMargin: 148
            anchors.left: parent.left
            anchors.leftMargin: 10
        }
    }
}
