// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1


Rectangle {
    id: container
    width: 300
    height: 75
    color: "transparent"
    radius: 8
    clip: true

    Component.onCompleted: {
        bridge.internetConnectionDown.connect(internetConnectionDown);
        bridge.internetConnectionUp.connect(internetConnectionUp);
        bridge.tcpServerConnectionDown.connect(tcpServerConnectionDown);
        bridge.tcpServerConnectionUp.connect(tcpServerConnectionUp);
        bridge.newPositionGPS.connect(newPositionGPS);
        bridge.isInternetAvailable();
    }

    Component.onDestruction: {
        bridge.internetConnectionDown.disconnect(internetConnectionDown);
        bridge.internetConnectionUp.disconnect(internetConnectionUp);
        bridge.tcpServerConnectionDown.disconnect(tcpServerConnectionDown);
        bridge.tcpServerConnectionUp.disconnect(tcpServerConnectionUp);
        bridge.newPositionGPS.disconnect(newPositionGPS);
    }

    property bool isCommander: false
    property alias name: lblPlayerInfo.text
    property alias totalMate: lblTotalMate.text
    property alias totalEnemy: lblTotalEnemy.text

    onIsCommanderChanged: {
        if (isCommander == true)
            imgDegree.source = "qrc:/images/" + bridge.getDeviceResolution() + "/rank2.png";
    }

    function internetConnectionDown() {
        mouseAreaToTcpReconnect.enabled = false;
        imgInternet.source = "qrc:/images/" + bridge.getDeviceResolution() + "/light_internet_off.png";
    }

    function internetConnectionUp() {
        mouseAreaToTcpReconnect.enabled = false;
        if (bridge.isTcpServerConnected())
            imgInternet.source = "qrc:/images/" + bridge.getDeviceResolution() + "/light_internet_on.png";
        else
            tcpServerConnectionDown();
    }

    function tcpServerConnectionDown() {
        mouseAreaToTcpReconnect.enabled = true;
        imgInternet.source = "qrc:/images/" + bridge.getDeviceResolution() + "/light_internet_red.png";
    }

    function tcpServerConnectionUp() {
        mouseAreaToTcpReconnect.enabled = false;
        internetConnectionUp();
    }

    //
    // level indica la qualita' dell'accuratezza orizzontale; numero alto indica qualita' buona: da zero a tre
    function newPositionGPS(level) {
        console.log(("update led gps"))
        imgGPS.source = "qrc:/images/" + bridge.getDeviceResolution() + "/light_gps_on.png";
        imgAccuracy.source = "qrc:/images/" + bridge.getDeviceResolution() + "/light_gpslevel" + level + ".png";
        timerStopGPSLed.start();
    }

    function getColor(alert) {
        return (alert ? "#87C503" : "white");
    }

    function setInfoMessage(alert, message) {
        ledScreenMsg1.text = ledScreenMsg.text;
        ledScreenMsg1.color = ledScreenMsg.color;
        ledScreenMsg.color = getColor(alert);
        ledScreenMsg.text = message;
        ledScreenMsg.opacity = 0.0;
    }

    function setInfoSystem(alert, message) {
        ledScreenSystem.color = getColor(alert);
        ledScreenSystem.text = message;
    }
    //
    // spegne il led del gps
    Timer {
        id: timerStopGPSLed
        interval: 1500
        onTriggered: imgGPS.source = "qrc:/images/" + bridge.getDeviceResolution() + "/light_gps_off.png";
    }

    Text {
        id: ledScreenMsg
        color: "#050404"
        anchors.bottom: ledScreenMsg1.top
        anchors.bottomMargin: 2
        anchors.top: parent.top
        anchors.topMargin: 48
        clip: true
        font.pixelSize: 11
        font.italic: false
        wrapMode: Text.WordWrap
        font.family: "verdana"
        font.bold: true
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
        anchors.right: imgAccuracy.left
        anchors.rightMargin: 10
        anchors.left: parent.left
        anchors.leftMargin: 2
        Behavior on opacity {
            NumberAnimation { property: "opacity"; from:0; to:1; duration: 1000; }
        }
    }

    Text {
        id: ledScreenMsg1
        height: 25
        clip: true
        anchors.bottom: separator.top
        anchors.bottomMargin: 2
        font.pixelSize: 11
        wrapMode: Text.WordWrap
        anchors.rightMargin: 10
        font.italic: false
        font.family: "verdana"
        font.bold: true
        anchors.right: imgAccuracy.left
        horizontalAlignment: Text.AlignHCenter
        anchors.leftMargin: 2
        verticalAlignment: Text.AlignVCenter
        anchors.left: parent.left
    }

    Rectangle {
        id:separator
        width: 326
        border.color: "#07cc11"
        height: 1
        anchors.bottom: ledScreenSystem.top
        anchors.bottomMargin: 0
        anchors.right: imgInternet.left
        anchors.rightMargin: 10
        anchors.left: parent.left
        anchors.leftMargin: 15
    }

    Text {
        id: ledScreenSystem
        height: 18
        clip: true
        font.pixelSize: 11
        font.italic: true
        wrapMode: Text.WordWrap
        font.family: "verdana"
        font.bold: true
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 2
        anchors.right: imgInternet.left
        anchors.rightMargin: 10
        anchors.left: parent.left
        anchors.leftMargin: 2
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
    }

    Text {
        id: lblPlayerInfo
        height: 32
        color: "white"
        style: Text.Outline
        font.family: "Impact"
        verticalAlignment: Text.AlignVCenter
        anchors.top: parent.top
        anchors.topMargin: 6
        anchors.right: lblTotalMate.left
        anchors.rightMargin: 32
        anchors.left: imgDegree.right
        anchors.leftMargin: 5
        font.pixelSize: bridge.getFontSizeMenu()
    }


    Text {
        id: lblTotalEnemy
        y: 0
        width: 27
        height: 32
        color: "#c41414"
        text: qsTr("0")
        font.pixelSize: 24
        anchors.top: parent.top
        anchors.topMargin: 6
        anchors.leftMargin: 310
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        anchors.left: parent.left
    }

    Text {
        id: lblTotalMate
        y: 0
        width: 27
        height: 32
        color: "#5668db"
        text: qsTr("0")
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        anchors.left: parent.left
        anchors.leftMargin: 240
        font.pixelSize: 24
        anchors.top: parent.top
        anchors.topMargin: 6
    }

    Image {
        id: imgDegree
        y: 41
        width: 29
        height: 31
        anchors.left: parent.left
        anchors.leftMargin: 6
        anchors.top: parent.top
        anchors.topMargin: 4
        fillMode: Image.PreserveAspectFit
        source: "qrc:/images/" + bridge.getDeviceResolution() + "/rank1.png"
        }

    Image {
        id: imgGPS
        width: 39
        height: 39
        sourceSize.height: 39
        sourceSize.width: 39
        anchors.top: parent.top
        anchors.topMargin: 1
        anchors.right: parent.right
        anchors.rightMargin: 1
        fillMode: Image.PreserveAspectFit
        source: "qrc:/images/" + bridge.getDeviceResolution() + "/light_gps_off.png"
    }

    Image {
        id: imgAccuracy
        width: 39
        height: 39
        anchors.top: imgGPS.bottom
        anchors.topMargin: 0
        source: "qrc:/images/" + bridge.getDeviceResolution() + "/light_gpslevel0.png"
        anchors.rightMargin: 1
        sourceSize.width: 39
        fillMode: Image.PreserveAspectFit
        sourceSize.height: 39
        anchors.right: parent.right
    }

    Image {
        id: imgInternet
        width: 39
        height: 39
        anchors.top: imgAccuracy.bottom
        anchors.topMargin: 0
        source: "qrc:/images/" + bridge.getDeviceResolution() + "/light_internet_off.png"
        anchors.rightMargin: 1
        sourceSize.width: 39
        fillMode: Image.PreserveAspectFit
        sourceSize.height: 39
        anchors.right: parent.right

        MouseArea {
            id: mouseAreaToTcpReconnect
            anchors.fill: parent
            enabled: false;
            z: 30

            onPressAndHold: {
                rumbleEffect.killRumble();
                bridge.tryTcpServerConnection();
                setInfoSystem(false, qsTr("richiesta connessione inviata"));
            }
        }
    }
}
