// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import QtMultimediaKit 1.1
import "../../../js/Navigator.js" as JNavigator
import "../../../js/Utility.js" as JUtility
import "../" // il file si trova in una directory diversa dagli altri oggetti, quindi importa la precedente radice


Page {
    id:navigatorGame
    orientationLock: PageOrientation.LockPortrait

    function rescueGame() {
        console.log("Navigator.qml: rescue!");
    }

    Component.onCompleted: {
        JNavigator.radius = bridge.getRadarRadius();
        bridge.communicationMsg.connect(JNavigator.communicationMsg);
        bridge.communicationPOI.connect(JNavigator.communicationPOI);
        bridge.respondToPOICommand.connect(JNavigator.respondToPOICommand);
        bridge.playerUnderAttack.connect(JNavigator.playerUnderAttack);
        bridge.playerKilled.connect(JNavigator.playerKilledNotification);
        bridge.updateNewStatusMap.connect(JNavigator.killGameRequestNotify); // per il proprietario non verra' mai lanciato il segnale
        bridge.commanderNotification.connect(setNicknameCommander); // deve precedere la chiamata a preparePlayers()
        bridge.infoAboutNumberPlayer.connect(JNavigator.infoAboutNumberPlayer); // deve precedere la chiamata a preparePlayers()
        bridge.preparePOIs(imgBackground, littleNavigator, bridge.preparePlayers(imgBackground));
        bridge.newZoomLevelSet.connect(JNavigator.zoomLevelSet);
        bridge.enemySpottedAlert.connect(JNavigator.enemySpottedAlert);
        bridge.targetAcquiredAlert.connect(JNavigator.targetAcquiredAlert);
        bridge.openMessageListNotify.connect(JNavigator.openMessageList);
        bridge.startNavigator();
    }

    Component.onDestruction: {
        bridge.updateNewStatusMap.disconnect(JNavigator.killGameRequestNotify);
        bridge.playerUnderAttack.disconnect(JNavigator.playerUnderAttack);
        bridge.playerKilled.disconnect(JNavigator.playerKilledNotification);
        bridge.commanderNotification.disconnect(setNicknameCommander);
        bridge.communicationMsg.disconnect(JNavigator.communicationMsg);
        bridge.communicationPOI.disconnect(JNavigator.communicationPOI);
        bridge.respondToPOICommand.disconnect(JNavigator.respondToPOICommand);
        bridge.enemySpottedAlert.disconnect(JNavigator.enemySpottedAlert);
        bridge.targetAcquiredAlert.disconnect(JNavigator.targetAcquiredAlert);
        bridge.openMessageListNotify.disconnect(JNavigator.openMessageList);
        bridge.infoAboutNumberPlayer.disconnect(JNavigator.infoAboutNumberPlayer);
        bridge.stopNavigator();
    }

    function setNicknameCommander(nick, playerName, isCommander) {
        littleNavigator.nicknameCommander = nick;
        lcdPanel.name = playerName;
        lcdPanel.isCommander = isCommander;
    }

    RadioVoiceControl {
        id: radioVoiceSound
    }

    SoundEffect {
        id: alertSound
        source: "../../../audio/popup.wav"
    }

    MessageListView {
        id: listMessage
        z: 50
        width: 430
        height: 600
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
    }

    RumbleEffect {
        id: rumbleEffect
    }

    Image {
        id: imgBackground
        clip: true
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        Component.onCompleted: source = "qrc:/images/" + bridge.getDeviceResolution() + "/radar.png"

        LedPanel {
            id: lcdPanel
            width: 390
            height: 124
            anchors.left: parent.left
            anchors.leftMargin: 45
            anchors.top: parent.top
            anchors.topMargin: 51

            Component.onCompleted: setInfoSystem(false, qsTr("Gioco sulla mappa avviato con successo!"))
        }

        EmbeddedNavigator {
            id: littleNavigator
            width: 480
            height: 197
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 0
        }

        Rectangle {
            id: zoomLevelContainer
            z: 1
            width: 456
            height: 456
            color: "#00000000"
            anchors.top: parent.top
            anchors.topMargin: 198
            anchors.left: parent.left
            anchors.leftMargin: 12
        }
    }
}
