// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import QtMultimediaKit 1.1
import "../../js/Resolution.js" as JResolution


Rectangle {
    id:dialog
    z: 100
    color: "transparent"

    Component.onCompleted: {
        dialog.width = JResolution.getWidth() - 40;
        dialog.height = JResolution.getHeight() / 3;
        dialog.hide();
    }

    property alias caption: caption.text
    property alias diagWidth: dialog.width
    property alias diagHeight: dialog.height
    property alias info: txtMessage.text
    property alias infoButton: cmdOk.caption
    property alias showButton: cmdOk.visible
    //
    // emesso al click del pulsante:
    signal clicked

    function show() {
        busyIndicator.visible = !dialog.showButton;
        dialog.opacity = 1;
        if (cmdOk.visible == false) {
            timeoutDialog.start();
            caption.text = qsTr("Attendere prego...");
        }
        else {
            caption.text = qsTr("Informazione utente");
            alertSound.play();
            timeoutDialog.stop();
        }
    }

    function hide() {
        dialog.opacity = 0;
        timeoutDialog.stop();
    }

    function isShown() {
        return (dialog.opacity == 1);
    }

    SoundEffect {
        id:alertSound
        source: "../../audio/popup.wav"
    }

    Timer {
        id: timeoutDialog
        interval: bridge.getRetryMillisecondTime()
        onTriggered: hide()
    }

    BorderImage {
        id: imgBackground
        source: "qrc:/images/panelPOS.png";
        verticalTileMode: BorderImage.Repeat
        horizontalTileMode: BorderImage.Repeat
        anchors.fill: dialog
        border.left: 27; border.top: 80
        border.right: 27; border.bottom: 50

        Text {
            id: txtMessage
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            color: "white"
            font.family: "Impact"
            wrapMode: Text.WordWrap
            anchors { right: parent.right; rightMargin: 20; left:parent.left; leftMargin: 20; bottom: cmdOk.top; bottomMargin: 10; top: parent.top; topMargin: 38 }

            Component.onCompleted: {
                if (JResolution.getHeight() === "640")
                    anchors.topMargin = 50;
                else if (JResolution.getHeight() === "854")
                    anchors.topMargin = 38;
                font.pointSize = bridge.getFontSizeText()
            }
        }

        Text {
            id: caption
            anchors.right: parent.right
            anchors.rightMargin: 15
            anchors.left: parent.left
            anchors.leftMargin: 15
            anchors.top: parent.top
            color: "#FAF567" //"#FAF567"
            font.italic: true
            font.family: "Impact"
            verticalAlignment: Text.AlignVCenter

            Component.onCompleted: {
                font.pointSize = bridge.getFontSizeMenu()
                if (JResolution.getHeight() === "640")
                    anchors.topMargin = 27;
                else if (JResolution.getHeight() === "854")
                    anchors.topMargin = 18;
            }
        }

        SoftairButton {
            id: cmdOk
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            z: 1
            onClickButton: {
                dialog.hide();
                dialog.showButton = false;
                clicked(); // emette il segnale
            }

            Component.onCompleted: {
                if (JResolution.getHeight() === "640")
                    anchors.bottomMargin = 25;
                else if (JResolution.getHeight() === "854")
                    anchors.bottomMargin = 40;
            }
        }

        Image {
            id: busyIndicator
            visible: false
            width: 67
            height: 66
            fillMode: Image.PreserveAspectFit
            source: "qrc:/images/light_time.png"
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 30

            Component.onCompleted: {
                if (JResolution.getHeight() === "640")
                    anchors.bottomMargin = 25;
                else if (JResolution.getHeight() === "854")
                    anchors.bottomMargin = 50;
            }
        }
    }
}
