// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import "../../js/Resolution.js" as JResolution

Rectangle {
    id:dialogInput
    color: "transparent"

    Component.onCompleted: {
        dialogInput.width = JResolution.getWidth() - 20;
        dialogInput.height = JResolution.getHeight() / 3;
        dialogInput.hide();
    }

    property alias diagWidth: dialogInput.width
    property alias diagHeight: dialogInput.height
    property alias info: lblCaption.text
    property alias inputText: txtInputValue.text
    property alias acceptButton: cmdOk.caption
    property alias cancelButton: cmdCancel.caption
    //
    // segnale emesso quando viene cliccato il pulsante della dialog:
    signal acceptClicked
    signal cancelClicked

    function show() {
        z = 100
        dialogInput.opacity = 1;
        dialogInput.inputText = "";
    }

    function hide() {
        dialogInput.opacity = 0;
    }

    function isShown() {
        return (dialogInput.opacity === 1);
    }

    BorderImage {
        id: imgBackground
        asynchronous: true
        source: "qrc:/images/panelPOS.png"
        verticalTileMode: BorderImage.Repeat
        horizontalTileMode: BorderImage.Repeat
        anchors.fill: parent
        border.left: 27; border.top: 80
        border.right: 27; border.bottom: 50

        Text {
            id: caption
            color: "#FAF567"
            style: Text.Outline
            font.family: "Impact"
            text: qsTr("Richiesta input")
            anchors.right: parent.right
            anchors.rightMargin: 15
            anchors.left: parent.left
            anchors.leftMargin: 15
            anchors.top: parent.top
            font.italic: true
            verticalAlignment: Text.AlignVCenter

            Component.onCompleted: {
                font.pointSize = bridge.getFontSizeMenu();
                if (JResolution.getHeight() === "640")
                    anchors.topMargin = 27;
                else if (JResolution.getHeight() === "854")
                    anchors.topMargin = 18;
            }
        }

        Text {
            id: lblCaption
            color: "white"
            font.family: "Impact"
            wrapMode: Text.WordWrap
            anchors { right: parent.right; rightMargin: 20; left:parent.left; leftMargin: 20; bottom: cmdOk.top; bottomMargin: 10; top: parent.top; topMargin: 80 }

            Component.onCompleted: {
                if (JResolution.getHeight() === "640")
                    anchors.topMargin = 70;
                else if (JResolution.getHeight() === "854")
                    anchors.topMargin = 80;
                font.pointSize = bridge.getFontSizeText()
            }
        }

        TextField {
            id: txtInputValue
            anchors.bottom: cmdOk.top
            anchors.left: parent.left
            anchors.leftMargin: 30
            anchors.right: parent.right
            anchors.rightMargin: 30

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    height = 35;
                    anchors.bottomMargin = 5;
                }
                else if (JResolution.getHeight() === "854") {
                    height = 45;
                    anchors.bottomMargin = 25;
                }
            }

            Keys.onReturnPressed: platformCloseSoftwareInputPanel();
        }

        SoftairButton {
            id: cmdOk
            anchors.left: parent.left
            anchors.leftMargin: 15
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            z: 1
            onClickButton: {
                dialogInput.acceptClicked();
                dialogInput.hide();
            }
        }
        SoftairButton {
            id: cmdCancel
            anchors.right: parent.right
            anchors.rightMargin: 15
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            z: 1
            onClickButton: {
                txtInputValue.text = "";
                dialogInput.cancelClicked();
                dialogInput.hide();
            }
        }
    }
}
