// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import QtMultimediaKit 1.1


Rectangle  {
    id: pathContainer
    color: "transparent"
    width: 440;
    height: 400

    property alias menuContext: path
    property alias textSize: path.textSize
    property alias textColor: path.textColor
    property alias imageSize: path.imageSize
    property alias delegate: path.delegate
    property alias model: path.model
    //
    // segnale emesso quando si seleziona una voce dal menu
    signal selectedVoice(variant index)
    //
    // aggiunta elementi del menu:
    function addVoice(voice, imageName) {
        menuModel.append( { name:voice, icon:imageName } );
    }

    SoundEffect {
        id:selectedSound
        source: "../../audio/voiceSelected.wav"
    }

    SoundEffect {
        id:movingSound
        source: "../../audio/move.wav"
    }
    //
    // Modello dati per il menu caricato dinamicamente
    ListModel  {
        id: menuModel
    }

    PathView  {
        id: path
        anchors.fill: parent
        delegate: pathContainer.delegate
        model: menuModel

        property real   textSize: 20
        property string textColor: "white"
        property real   imageSize: 200

        onMovementStarted: {
            movingSound.play()
        }

        onMovementEnded: {
            info.text = menuModel.get(path.currentIndex).name;
        }

        path: Path  {
            startX: pathContainer.width / 2; startY: pathContainer.height / 2
            PathAttribute  { name: "iconScale"; value: 1.7 }
            PathAttribute  { name: "iconOpacity"; value: 1.0 }
            PathQuad  { x: pathContainer.width / 2; y: 25; controlX: pathContainer.width + 80; controlY: 200 }
            PathAttribute  { name: "iconScale"; value: 0.0 }
            PathAttribute  { name: "iconOpacity"; value: 0.0 }
            PathAttribute  { name: "zIndex"; value: -1 }
            PathQuad  { x: pathContainer.width / 2; y: pathContainer.height / 2; controlX: -20; controlY: 200 }
        }
    }

    Text {
        id: info
        height: 70
        color: "#FAF567"//"#FAF567"
        style: Text.Outline
        font.family: "Impact"
        font.pointSize: path.textSize
        font.bold: true
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
        anchors { right: parent.right; rightMargin: 0; left: parent.left; leftMargin: 0; bottom: parent.bottom; bottomMargin: 0; }

        Component.onCompleted: info.text = menuModel.get(path.currentIndex).name;
    }
}
