import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import "../../js/authenticate.js" as JScript
import "../../js/Resolution.js" as JResolution
import "inneractive"

Page {
    id: page
    orientationLock: PageOrientation.LockPortrait
    //
    // connessa al segnale di recupero ultimo gioco: result indica se c'e' un valido recupero;
    function isLastGameRescued(result, msg, qmlFile, inGame) {
        if (result === true) {
            dialogInfo.info = qsTr("Attendere caricamento gioco...");
            dialogInfo.showButton = false;
            dialogInfo.show();
            var page = pageStack.push(Qt.resolvedUrl(qmlFile));

            page.rescueGame(inGame);
        }
        else {
            dialogInfo.info = msg;
            dialogInfo.showButton = true;
            dialogInfo.show();
        }
    }
    //
    // richiamata quando viene emesso l'omonimo segnale dal backend
    function rescueProcessInProgress() {
        dialogInfo.info = qsTr("Avvio processo di recupero partita...");
        dialogInfo.showButton = false;
        dialogInfo.show();
    }
    //
    // utilizzata solo per la notifica di avvio automatica
    Timer {
        id: delayNotificationOnStart
        interval: 500
        onTriggered: toolTip.showBallon(qsTr("Swipe left/right to navigate"), "qrc:/images/light_info.png", 3500)
    }

    Image {
        id: imgBackground
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        source: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/mainBackground.jpg"

        onVisibleChanged: if (visible == true) delayNotificationOnStart.start();

        Component.onCompleted: {
            bridge.rescueProcessInProgress.connect(rescueProcessInProgress);
            bridge.isLastGameRescued.connect(isLastGameRescued);
            bridge.authInProgress.connect(JScript.authInProgress);
            bridge.isAuthenticated.connect(JScript.isAuthenticated);
            bridge.setBusyUser(false, "");
            bridge.selectedOnlineMap(0, 0, "");
            bridge.setCommander(false);
            bridge.setEnemy(false);
            dialogInfo.hide();
        }

        Component.onDestruction: {
            bridge.rescueProcessInProgress.disconnect(rescueProcessInProgress);
            bridge.isLastGameRescued.disconnect(isLastGameRescued);
            bridge.authInProgress.disconnect(JScript.authInProgress);
            bridge.isAuthenticated.disconnect(JScript.isAuthenticated);
        }

        AdItem {
            width:350
            height:50
            z:100
            parameters: AdParameters {
                applicationId: "Individual_SoftairRealFight_Nokia"
            }
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter
        }

        DialogInfo {
            id:dialogInfo
            infoButton: qsTr("Chiudi");
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
        }

        Text {
            id: infoVersion
            height: 70
            color: "#FAF567"//"#FAF567"
            style: Text.Outline
            font.family: "Impact"
            text: qsTr("vers. 2.0")
            font.pointSize: 10
            anchors.bottom: mainMenu.top
            anchors.bottomMargin: -38
            anchors.rightMargin: 60
            anchors.right: parent.right

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    infoVersion.font.pointSize = 5;
                    infoVersion.anchors.bottomMargin = -40;
                }
            }
        }
        //
        // Menu che carica le voci
        GenericMenu {
            id: mainMenu
            anchors.right: parent.right
            anchors.rightMargin: 0
            anchors.left: parent.left
            anchors.leftMargin: 0
            anchors.top: parent.top
            anchors.topMargin: 210
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 100
            delegate: GenericMenuDelegate {}

            onSelectedVoice: {
                if (index === 0) { // Manage map
                    JScript.pageToCall = "MapGameOnline.qml";
                    bridge.authenticate(); // tenta autenticazione sul server
                }
                else if (index === 1) { // Partecipate Map
                    JScript.pageToCall = "PlayGameOnline.qml";
                    bridge.authenticate(); // tenta autenticazione sul server
                }
                else if (index === 2) { // Game Settings
                   pageStack.push(Qt.resolvedUrl("Settings.qml"));
                }
                else if (index === 3) { // Rescue Game
                   bridge.tryToRescueLastGame(); // avvia il recupero
                }
            }

            Component.onCompleted: {
                var rootimage = "qrc:/images";

                if (JResolution.getHeight() === "640") {
                    anchors.topMargin = 160;
                    anchors.bottomMargin = 70;
                }
                mainMenu.textSize = bridge.getFontSizeMenu();
                mainMenu.imageSize = bridge.getImageSizeMenu();
                mainMenu.addVoice(qsTr("START NEW GAME"), rootimage + "/menuManageMap.png");
                mainMenu.addVoice(qsTr("PARTECIPATE TO GAME"), rootimage + "/menuPlayMap.png");
                mainMenu.addVoice(qsTr("GAME SETTINGS"), rootimage + "/menuSettings.png");
                if (bridge.needToRescueGame()) // verifica se ci sono dati inerenti una precedente partita
                    mainMenu.addVoice(qsTr("GAME RECOVERY"), rootimage + "/menuRescueGame.png");
            }
        }
    }
}
