// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import QtMultimediaKit 1.1
import "../../js/searchUserMap.js" as JUserMap
import "../../js/Participation.js" as JScriptParticipation
import "../../js/Resolution.js" as JResolution

Page {
    id:manageGameOnline
    orientationLock: PageOrientation.LockPortrait

    Component.onCompleted: {
        bridge.searchUserMapInProgress.connect(JUserMap.searchUserMapInProgress);
        bridge.searchUserMapCompleted.connect(JUserMap.searchUserMapCompleted);
        bridge.updateMapList.connect(JUserMap.updateMapList);
        bridge.clearSearchResult();
    }

    Component.onDestruction: {
        bridge.searchUserMapInProgress.disconnect(JUserMap.searchUserMapInProgress);
        bridge.searchUserMapCompleted.disconnect(JUserMap.searchUserMapCompleted);
        bridge.updateMapList.disconnect(JUserMap.updateMapList);
    }

    SoundEffect {
        id:selectedSound
        source: "../../audio/voiceSelected.wav"
    }

    DialogInfo {
        id:dialogInfo
        infoButton: qsTr("Chiudi");
        anchors.horizontalCenter: manageGameOnline.horizontalCenter
        anchors.verticalCenter: manageGameOnline.verticalCenter
    }

    DialogInput {
        id:dialogInputMapPasswd
        info: qsTr("Inserire password di accesso alla mappa per attivare la modalita' attesa giocatori:")
        acceptButton: qsTr("Accetta");
        cancelButton: qsTr("Annulla")
        anchors.horizontalCenter: manageGameOnline.horizontalCenter
        anchors.verticalCenter: manageGameOnline.verticalCenter

        function onClickAccepted() {
            bridge.setCommander(switchCommander.checked);
            JUserMap.startGameOnMap();
            rectList.enabled = true;
        }

        Component.onCompleted: dialogInputMapPasswd.acceptClicked.connect(onClickAccepted);

        Component.onDestruction: {
            dialogInputMapPasswd.acceptClicked.disconnect(onClickAccepted);
        }
    }

    Image {
        id: imgBackground
        fillMode: Image.PreserveAspectFit
        source: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/background.jpg"

        Component.onCompleted: {
            // importante questa modalita' in quanto all'apertura della tastiera evita di comprimere il form
            imgBackground.width = JResolution.getWidth();
            imgBackground.height = JResolution.getHeight();
        }

        Text {
            id: labelSearch
            text: qsTr("Tue mappe")
            color: "#FAF567"
            style: Text.Outline
            font.family: "Impact"
            font.pointSize: bridge.getFontSizeMenu()
            width: 160
            anchors.top: parent.top
            anchors.topMargin: 220
            anchors.left: parent.left
            anchors.leftMargin: 20

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.topMargin = 180;
                    width = 130;
                }
            }
        }

        TextField {
            id: txtMapName
            height: 45
            smooth: true
            anchors.top: parent.top
            anchors.topMargin: 215
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.left: labelSearch.right
            anchors.leftMargin: 10

            onActiveFocusChanged: bridge.clearSearchResult()

            Keys.onReturnPressed: platformCloseSoftwareInputPanel();

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.topMargin = 175;
                    height = 35;
                    anchors.leftMargin = 14;
                }
            }
        }

        SoftairButton {
            id: buttonSearch
            width: 219
            height: 49
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: 10
            caption: qsTr("Trova")

            onClickButton: {
                if (JScriptParticipation.isAnyDialogShown() === false) {
                    bridge.clearSearchResult(); // pulisce la lista
                    bridge.setEnemy(false); // sara' sempre false per il possessore della mappa
                    rectList.enabled = true;
                    bridge.searchUserMapOnline(txtMapName.text.trim());
                }
            }
        }

        SearchMapListView {
            id: rectList
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.top: txtMapName.bottom
            anchors.topMargin: 15
            anchors.bottom: switchCommander.top
            anchors.bottomMargin: 20

            onSelectedVoice: {
                if (JScriptParticipation.isAnyDialogShown() === false) {
                    if (rectList.listMap.currentIndex > -1) // mappa selezionata
                        if (dialogInputMapPasswd.isShown() === false) dialogInputMapPasswd.show();
                }
            }
        }

        RumbleEffect {
            id: rumbleEffect
        }

        SwitchImage {
            id: switchCommander
            height: 30
            anchors { left: parent.left; leftMargin: 20; bottom: cmdBack.top; bottomMargin: 20; right: parent.right; rightMargin: 20 }
            imageNotChecked: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/rank1.png"
            imageChecked: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/rank2.png"
            caption: qsTr("Grado nel gioco")
            sizeCaption: bridge.getFontSizeMenu()

            Component.onCompleted: {
                if (JResolution.getHeight() === "854") {
                    imageWidth = 29;
                    imageHeight = 31
                }
                else if (JResolution.getHeight() === "640") {
                    imageWidth = 22;
                    imageHeight = 23
                }
            }

            onClickChecked: rumbleEffect.killRumble()
        }

        SoftairButton {
            id: cmdBack
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 20
            caption: qsTr("Indietro")
            onClickButton: {
                if (JScriptParticipation.isAnyDialogShown() === false)
                    pageStack.pop();
            }
        }
    }
}
