// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import QtMultimediaKit 1.1
import "../../js/listPlayer.js" as JListPlayer
import "../../js/Resolution.js" as JResolution
import "inneractive"

Page {
    id:lobbyGame
    orientationLock: PageOrientation.LockPortrait

    function rescueGame(inGame) {
        if (inGame) {
            cmdBack.visible = false;
            cmdOpenMap.visible = false;
            rescueTimer.start(); // necessario delay affinche' su MeeGo non si blocchi l'interfaccia del navigatore
        }
        else {
            console.log("notification abilitate")
            bridge.activateTcpServerNotification(); // se non in gioco, e' in waiting quindi abilita le notifiche (se in gioco avviava le notifiche nel navigatore)
        }
    }

    Component.onCompleted: {
        bridge.retrivePlayerListInProgress.connect(JListPlayer.retrivePlayerListInProgress);
        bridge.retrivePlayerListCompleted.connect(JListPlayer.retrivePlayerListCompleted);
        bridge.waitingMapPlayer.connect(JListPlayer.notificationOnMap);
        bridge.updateList.connect(JListPlayer.updatePlayerList);
        bridge.retrivePlayersInMap(); // necessaria per aggiornare la lista con il primo partecipante alla mappa: il proprietario stesso
    }

    Component.onDestruction: {
        bridge.retrivePlayerListInProgress.disconnect(JListPlayer.retrivePlayerListInProgress);
        bridge.retrivePlayerListCompleted.disconnect(JListPlayer.retrivePlayerListCompleted);
        bridge.waitingMapPlayer.disconnect(JListPlayer.notificationOnMap);
        bridge.updateList.disconnect(JListPlayer.updatePlayerList);
    }

    Timer {
        id: rescueTimer
        interval: 500
        onTriggered: JListPlayer.startGamePlayOnMap()
    }

    SoundEffect {
        id: joinInSound
        source: "../../audio/join.wav"
    }

    DialogInfo {
        id:dialogInfo
        z:100
        infoButton: qsTr("Chiudi");
        anchors.horizontalCenter: lobbyGame.horizontalCenter
        anchors.verticalCenter: lobbyGame.verticalCenter
    }

    Image {
        id: imgBackground
        anchors.fill: parent
        fillMode: Image.PreserveAspectFit
        source: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/background.jpg"

        /*
        Text {
            id: labelSearch
            text: bridge.getNameOfOpenedMap()
            anchors.top: imgBackground.top
            anchors.topMargin: 10
            color: "yellow"
            anchors.right: imgBackground.right
            anchors.rightMargin: 50
            font.italic: true
            font.pixelSize: 40
        }
        */

        AdItem {
            width:350
            height:50
            z:100
            parameters: AdParameters {
                applicationId: "Individual_SoftairRealFight_Nokia"
            }
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter
        }

        PlayerListView {
            id: listTeamOne
            height: 270
            headerImageName: "helmet_blue.png"
            headerCaption: qsTr("Team amici")
            anchors.top: parent.top
            anchors.topMargin: 220
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 20

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.topMargin = 165;
                    height = 195;
                }
            }
        }

        PlayerListView {
            id: listTeamTwo
            height: 270
            headerImageName: "helmet_red.png"
            headerCaption: qsTr("Team nemici")
            anchors.top: listTeamOne.bottom
            anchors.topMargin: 15
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 20

            Component.onCompleted: {
                if (JResolution.getHeight() === "640")
                    height = 195;
            }
        }

        SoftairButton {
            id: cmdBack
            width: 219
            height: 49
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 20
            caption: qsTr("Indietro")
            onClickButton: {
                if (dialogInfo.isShown() === false)
                    JListPlayer.closeWaitingMap();
            }
        }

        SoftairButton {
            id: cmdOpenMap
            width: 219
            height: 49
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: 20
            caption: qsTr("Avvia gioco")
            onClickButton: {
                if (dialogInfo.isShown() === false) {
                    JListPlayer.startGamePlayOnMap();
                }
            }
        }
    }
}
