// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import "../../js/Resolution.js" as JResolution

Item {
    id: rectList
    visible: false

    property alias  caption: lblCaption.text
    property alias  listMessage: listMessage
    property int    idObject: 0
    property bool   isPOI: false

    function hide() {
        rectList.visible = false;
        listMessage.currentIndex = -1;
    }

    BorderImage {
        id: backImage
        anchors.fill: parent
        source: "qrc:/images/panelPOS.png"
        verticalTileMode: BorderImage.Stretch
        horizontalTileMode: BorderImage.Stretch
        border.left: 27; border.top: 80
        border.right: 27; border.bottom: 50
    }

    ListView {
        id: listMessage
        spacing: 3
        anchors.top: parent.top
        anchors.topMargin: 70
        anchors.right: parent.right
        anchors.rightMargin: 0
        anchors.left: parent.left
        anchors.leftMargin: 0
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20
        currentIndex: -1
        clip: true
        focus: true
        orientation: ListView.Vertical
        delegate: MessageDelegate {}
        model: messageModel // settato nel context in Communicator.cpp

        onCurrentIndexChanged: {
            if (listMessage.currentIndex > -1)
                rectList.visible = false;
        }
    }

    Image {
        id: imgClose
        z: 20
        fillMode: Image.PreserveAspectFit
        anchors.right: parent.right
        anchors.rightMargin: 20
        anchors.top: parent.top
        source: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/erasePOI.png"

        Component.onCompleted: {
            if (JResolution.getHeight() === "854") {
                anchors.topMargin = 15;
                width = 33;
                height = 42
            }
            else if (JResolution.getHeight() === "640") {
                anchors.topMargin = 18;
                width = 25;
                height = 32
            }
        }

        MouseArea {
            id: areaClose
            anchors.fill: parent

            onPressed: hide()
        }
    }

    Row {
        spacing: 5
        anchors.right: imgClose.right
        anchors.rightMargin: 20
        anchors.top: parent.top
        anchors.topMargin: 20
        anchors.left: parent.left
        anchors.leftMargin: 20

        Image {
            id: imgLogo
            smooth: true
            source: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/button_ico_msg.png"
            fillMode: Image.PreserveAspectFit
            width:33
            height: 33
        }

        Text {
            id: lblCaption
            height: 30
            color: "#FAF567"
            style: Text.Outline
            font.family: "Impact"
            text: qsTr("Invia comunicazione")
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter

            Component.onCompleted: font.pointSize = bridge.getFontSizeMenu()
        }
    }
}
