// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import QtMultimediaKit 1.1
import "../../js/searchMap.js" as JScript
import "../../js/checkMessage.js" as JScriptCheck
import "../../js/Participation.js" as JScriptParticipation
import "../../js/JoinOut.js" as JScriptJoinOut
import "../../js/retriveStatusMap.js" as JStatusMapRetriver
import "../../js/listPlayer.js" as JListPlayer
import "../../js/Resolution.js" as JResolution
import "inneractive"

Page {
    id:playGameOnline
    orientationLock: PageOrientation.LockPortrait

    property bool globalInGame: false
    //
    // eseguita per effettuare il rescue in attesa
    function rescueGame(inGame) {
        if (inGame) {
            cmdBack.visible = false;
            cmdSitOut.visible = false;
            buttonSearch.visible = false;
        }
        playGameOnline.globalInGame = inGame;
        rescueTimer.start(); // necessario delay affinche' su MeeGo non si blocchi l'interfaccia del navigatore
    }

    Component.onCompleted: {
        bridge.retrivePlayerListInProgress.connect(JListPlayer.retrivePlayerListInProgress);
        bridge.retrivePlayerListCompleted.connect(JListPlayer.retrivePlayerListCompleted);
        bridge.waitingMapPlayer.connect(JListPlayer.notificationOnMap);
        bridge.updateList.connect(JListPlayer.updatePlayerList);
        bridge.searchMapInProgress.connect(JScript.searchMapInProgress);
        bridge.searchMapCompleted.connect(JScript.searchMapCompleted);
        bridge.checkParticipationInProgress.connect(JScriptCheck.checkParticipationInProgress);
        bridge.joinInProgress.connect(JScriptParticipation.joinInProgress);
        bridge.isJoinedInMap.connect(JScriptParticipation.isJoinedInMap);
        bridge.joinOutProgress.connect(JScriptJoinOut.joinOutProgress);
        bridge.isJoinedOutFromMap.connect(JScriptJoinOut.isJoinedOutFromMap);
        bridge.updateMapList.connect(JScript.updateMapList);
        bridge.clearSearchResult();
    }

    Component.onDestruction: {
        bridge.retrivePlayerListInProgress.disconnect(JListPlayer.retrivePlayerListInProgress);
        bridge.retrivePlayerListCompleted.disconnect(JListPlayer.retrivePlayerListCompleted);
        bridge.waitingMapPlayer.disconnect(JListPlayer.notificationOnMap);
        bridge.updateList.disconnect(JListPlayer.updatePlayerList);
        bridge.searchMapInProgress.disconnect(JScript.searchMapInProgress);
        bridge.searchMapCompleted.disconnect(JScript.searchMapCompleted);
        bridge.checkParticipationInProgress.disconnect(JScriptCheck.checkParticipationInProgress);
        bridge.joinInProgress.disconnect(JScriptParticipation.joinInProgress);
        bridge.isJoinedInMap.disconnect(JScriptParticipation.isJoinedInMap);
        bridge.joinOutProgress.disconnect(JScriptJoinOut.joinOutProgress);
        bridge.isJoinedOutFromMap.disconnect(JScriptJoinOut.isJoinedOutFromMap);
        bridge.updateMapList.disconnect(JScript.updateMapList);
    }

    Timer {
        id: rescueTimer
        interval: 500
        onTriggered: {
            if (playGameOnline.globalInGame === true)
                JListPlayer.startGamePlayOnMap();
            else { // in attesa inizio gioco
                JScriptParticipation.isJoinedInMap(true, "");
                bridge.activateTcpServerNotification(); // se non in gioco, e' in waiting quindi abilita le notifiche (se in gioco avviava le notifiche nel navigatore)
            }
        }
    }

    SoundEffect {
        id:selectedSound
        source: "../../audio/voiceSelected.wav"
    }

    DialogInfo {
        id:dialogInfo
        infoButton: qsTr("Chiudi");
        anchors.horizontalCenter: playGameOnline.horizontalCenter
        anchors.verticalCenter: playGameOnline.verticalCenter
    }

    DialogInput {
        id:dialogInputMapPasswd
        diagWidth: 400
        diagHeight: 200
        info: qsTr("Inserire password di accesso alla mappa per effettuare la partecipazione:")
        acceptButton: qsTr("Accetta");
        cancelButton: qsTr("Annulla")
        anchors.horizontalCenter: playGameOnline.horizontalCenter
        anchors.verticalCenter: playGameOnline.verticalCenter

        function onClickAccepted() {
            bridge.setEnemy(switchEnemy.checked);
            bridge.setCommander(switchCommander.checked);
            JScriptParticipation.joinInMap();
        }

        Component.onCompleted: {
            dialogInputMapPasswd.acceptClicked.connect(onClickAccepted);
            dialogInputMapPasswd.hide();
        }

        Component.onDestruction: {
            dialogInputMapPasswd.acceptClicked.disconnect(onClickAccepted);
        }
    }

    WaitPanel {
        id:panelWait
        anchors.bottomMargin: 80
        anchors.fill: parent
        caption: qsTr("Attendere avvio della partita...")
        z:10

        function newMapStatus(status) {
            if (status === JScriptCheck.getMapStatus(JScriptCheck.SWITCH_MAP_STATUS_TO_END)) {
                cmdSitOut.visible = false;
                buttonSearch.visible = true;
                panelWait.visible = false;
                rectList.enabled = true;
                dialogInfo.info = qsTr("La mappa e' stata chiusa dal proprietario!");
                dialogInfo.showButton = true;
                dialogInfo.show();
            }
            else if (status === JScriptCheck.getMapStatus(JScriptCheck.SWITCH_MAP_STATUS_TO_PLAY))
                JListPlayer.startGamePlayOnMap();
        }
        //
        // verifica lo stato della mappa e se in gioco, avvia la procedura di download dei dati e inizia il gioco
        function startGameIfInPlay(status) {
            console.log("Controllo se la mappa e' in gioco...");
            if (status === JScriptCheck.getMapStatus(JScriptCheck.SWITCH_MAP_STATUS_TO_PLAY))
                JListPlayer.startGamePlayOnMap();
            else {
                dialogInfo.showButton = true;
                dialogInfo.info = qsTr("La mappa non e' in modalita' gioco: attendere l'avvio del gioco!");
                dialogInfo.show();
            }
        }

        Component.onCompleted: {
            if (JResolution.getHeight() === "640")
                anchors.bottomMargin = 60;
            panelWait.visible = false;
            bridge.retriveStatusMapInProgress.connect(JStatusMapRetriver.retriveStatusMapInProgress);
            bridge.retriveStatusMapCompleted.connect(JStatusMapRetriver.retriveStatusMapCompleted);
            JStatusMapRetriver.callbackStatusRetrived = startGameIfInPlay;
            panelWait.clickStartGame.connect(bridge.retriveStatusMap);
            bridge.updateNewStatusMap.connect(newMapStatus);
        }
        Component.onDestruction: {
            panelWait.clickStartGame.disconnect(bridge.retriveStatusMap);
            bridge.retriveStatusMapInProgress.disconnect(JStatusMapRetriver.retriveStatusMapInProgress);
            bridge.retriveStatusMapCompleted.disconnect(JStatusMapRetriver.retriveStatusMapCompleted);
            bridge.updateNewStatusMap.disconnect(newMapStatus);
        }

        AdItem {
            width:350
            height:80
            z:100
            parameters: AdParameters {
                applicationId: "Individual_SoftairRealFight_Nokia"
            }
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.horizontalCenter: parent.horizontalCenter
        }

    }


    Image {
        id: imgBackground
        fillMode: Image.PreserveAspectFit
        source: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/background.jpg"

        Component.onCompleted: {
            // importante questa modalita' in quanto all'apertura della tastiera evita di comprimere il form
            imgBackground.width = JResolution.getWidth();
            imgBackground.height = JResolution.getHeight();
        }


        SearchMapListView {
            id: rectList
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.top: txtMapName.bottom
            anchors.topMargin: 15
            anchors.bottom: switchEnemy.top
            anchors.bottomMargin: 20
            caption: qsTr("Mappe in attesa")

            onSelectedVoice: {
                if (JScriptParticipation.isAnyDialogShown() === false && panelWait.isShown() === false) {
                    if (rectList.listMap.currentIndex > -1) // mappa selezionata
                        if (dialogInputMapPasswd.isShown() === false) dialogInputMapPasswd.show();
                }
            }
        }

        Text {
            id: labelSearch
            text: qsTr("Ricerca mappa")
            width: 160
            color: "#FAF567"
            style: Text.Outline
            font.pointSize: bridge.getFontSizeMenu()
            font.family: "Impact"
            anchors.top: parent.top
            anchors.topMargin: 220
            anchors.left: parent.left
            anchors.leftMargin: 20

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.topMargin = 180;
                    width = 130;
                }
            }
        }

        TextField {
            id: txtMapName
            height: 45
            smooth: true
            anchors.top: parent.top
            anchors.topMargin: 215
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.left: labelSearch.right
            anchors.leftMargin: 10

            onActiveFocusChanged: bridge.clearSearchResult()

            Keys.onReturnPressed: platformCloseSoftwareInputPanel();

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.topMargin = 175;
                    height = 35;
                    anchors.leftMargin = 14;
                }
            }
        }

        RumbleEffect {
            id: rumbleEffect
        }

        SwitchImage {
             id: switchEnemy
             height: 30
             anchors { left: parent.left; leftMargin: 20; bottom: cmdBack.top; bottomMargin: 55; }
             imageNotChecked: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/helmet_blue.png"
             imageChecked: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/helmet_red.png"
             caption: qsTr("Raggruppamento")
             sizeCaption: bridge.getFontSizeMenu()

             Component.onCompleted: {
                 if (JResolution.getHeight() === "854") {
                     imageWidth = 29;
                     imageHeight = 20;
                 }
                 else if (JResolution.getHeight() === "640") {
                     imageWidth = 22;
                     imageHeight = 15;
                 }
             }

             onClickChecked: rumbleEffect.killRumble()
        }

        SwitchImage {
            id: switchCommander
            height: 30
            anchors { left: parent.left; leftMargin: 20; top: switchEnemy.bottom; topMargin: 10 }
            imageNotChecked: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/rank1.png"
            imageChecked: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/rank2.png"
            caption: qsTr("Grado nel gioco")
            sizeCaption: bridge.getFontSizeMenu()

            Component.onCompleted: {
                if (JResolution.getHeight() === "854") {
                    imageWidth = 29;
                    imageHeight = 31
                }
                else if (JResolution.getHeight() === "640") {
                    imageWidth = 22;
                    imageHeight = 23
                }
            }

            onClickChecked: rumbleEffect.killRumble()
        }

        SoftairButton {
            id: cmdBack
            width: 219
            height: 49
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 10
            caption: qsTr("Indietro")

            onClickButton: {
                if (JScriptParticipation.isAnyDialogShown() === false) {
                    // esegue verifica per controllare se l'utente sta partecipando a qualche mappa: risultato gestito in checkMessage.js
                    bridge.isPlayerJoinedInMap.connect(JScriptCheck.isPlayerJoinedInMap);
                    bridge.checkParticipationInMap();
                }
            }
        }

        SoftairButton {
            id: buttonSearch
            width: 219
            height: 49
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: 10
            caption: qsTr("Trova")

            onClickButton: {
                if (JScriptParticipation.isAnyDialogShown() === false) {
                    rectList.enabled = true;
                    bridge.searchMapOnline(txtMapName.text.trim());
                }
            }
        }

        SoftairButton {
            id: cmdSitOut
            width: 219
            height: 49
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: 10
            caption: qsTr("Deregistra")

            onClickButton: {
                if (JScriptParticipation.isAnyDialogShown() === false) {
                    cmdSitOut.visible = false;
                    buttonSearch.visible = true;
                    bridge.joinOutMap();
                }
            }
            Component.onCompleted: cmdSitOut.visible = false;
        }
    }
}
