// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import "../../js/Resolution.js" as JResolution


Rectangle {
    id: rectList
    z: 0
    radius: 8
    color: "transparent"

    property alias  listTeamPlayer: listPlayers
    property alias  headerCaption: caption.text
    property alias  headerCounter: counter.text
    property string headerImageName: ""

    onHeaderImageNameChanged: {
        imgLogo.source = "qrc:/images/" + JResolution.getJsDeviceResolution() + "/" + headerImageName;
    }

    //
    // aggiunge elementi nella lista, pulendola prima dai vecchi elementi
    function addElements(list) {
        innerModel.clear();
        for (var i = 0; i < list.length; i++)
            rectList.appendItem(list[i].idUsername, list[i].nickname, list[i].commander);
    }
    //
    // aggiunge un nuovo elemento alla lista:
    function appendItem(id_username, nickname, commander) {
        innerModel.append({"nickname":nickname, "commander":commander, "idUsername":id_username});
    }
    //
    // elimina una voce dalla lista:
    function removeItem(id_username) {
        var indexToRemove = -1;
        //
        // cicla alla ricerca dell'elemento da eliminare, tramite id username:
        for (var i = 0; i < innerModel.count; i++) {
            if (innerModel.get(i).idUsername === id_username) {
                indexToRemove = i;
                break; // esce dal ciclo per eliminare l'elemento
            }
        }
        if (indexToRemove > -1)
            innerModel.remove(indexToRemove);
        return (indexToRemove > -1); // true se e' stato trovato l'id e quindi eliminato
    }

    BorderImage {
        id: imgBackground
        anchors.fill: parent
        source: "qrc:/images/list.png"
        verticalTileMode: BorderImage.Repeat
        horizontalTileMode: BorderImage.Repeat
        border.left: 12; border.top: 54
        border.right: 12; border.bottom: 12
        //
        // modello che sara' caricato dinamicamente
        ListModel {
            id:innerModel
            ListElement { nickname:"" }
            ListElement { commander:0 }
            ListElement { idUsername:0 }
        }

        Text {
            id: caption
            color: "white"
            style: Text.Outline
            font.family: "Impact"
            anchors.right: parent.right
            anchors.rightMargin: 14
            anchors.top: parent.top
            anchors.topMargin: 10
            anchors.left: parent.left
            anchors.leftMargin: 15
            height: 30
            verticalAlignment: Text.AlignVCenter

            Component.onCompleted: font.pointSize = bridge.getFontSizeMenu()
        }

        Image {
            id: imgLogo
            anchors.right: counter.left
            anchors.rightMargin: 10
            anchors.top: parent.top
            fillMode: Image.PreserveAspectFit

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.topMargin = 15;
                    width = 22;
                    height = 15;
                }
                else if (JResolution.getHeight() === "854") {
                    anchors.topMargin = 18;
                    width = 29;
                    height = 20;
                }
            }
        }

        Text {
            id: counter
            width: 25
            color: "white"
            style: Text.Outline
            font.family: "Impact"
            text: "0"
            horizontalAlignment: Text.AlignHCenter
            anchors.right: parent.right
            anchors.rightMargin: 14
            anchors.top: parent.top
            anchors.topMargin: 10
            verticalAlignment: Text.AlignVCenter

            Component.onCompleted: font.pointSize = bridge.getFontSizeMenu()
        }

        ListView {
            id: listPlayers
            spacing: 3
            clip: true
            anchors.top: parent.top
            anchors.topMargin: 56
            anchors.right: parent.right
            anchors.rightMargin: 12
            anchors.left: parent.left
            anchors.leftMargin: 12
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            model: innerModel
            orientation: ListView.Vertical
            delegate: PlayerTeamDelegate {}
        }
    }
}
