// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0 //import com.nokia.symbian 1.1
import QtMultimediaKit 1.1
import "../../js/Resolution.js" as JResolution

Page {
    id:setting
    orientationLock: PageOrientation.LockPortrait

    Component.onCompleted: {
        bridge.isSettingsUpdated.connect(newSettingUpdated);
        bridge.settingsLoaded.connect(seattingsLoaded);
        bridge.loadSettings();
    }

    Component.onDestruction: {
        bridge.isSettingsUpdated.disconnect(newSettingUpdated);
        bridge.settingsLoaded.disconnect(seattingsLoaded);
    }

    function newSettingUpdated() {
        dialogInfo.info = qsTr("Aggiornamento delle impostazioni avvenuto con successo!");
        dialogInfo.showButton = true;
        dialogInfo.show();
    }

    function seattingsLoaded(nickname, password, server, port) {
        txtPassword.text = password;
        txtUsername.text = nickname;
        txtRemoteServer.text = server;
        txtRemoteServerPort.text = port;
    }

    SoundEffect {
        id: linkSound
        source: "../../audio/click.wav"
    }

    DialogInfo {
        id:dialogInfo
        infoButton: qsTr("Chiudi");
        anchors.horizontalCenter: setting.horizontalCenter
        anchors.verticalCenter: setting.verticalCenter
    }

    Image {
        id: imgBackground
        fillMode: Image.PreserveAspectFit
        source: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/background.jpg"
        transform: Translate { id:translate }

        Component.onCompleted: {
            // importante questa modalita' in quanto all'apertura della tastiera evita di comprimere il form
            imgBackground.width = JResolution.getWidth();
            imgBackground.height = JResolution.getHeight();
        }

        MouseArea {
            anchors.fill: parent

            onClicked: if (JResolution.getHeight() === "640") translate.y = 0;
        }

        Text {
            id: labelRemoteServer
            height: 30
            text: qsTr("Server remoto:")
            color: "#FAF567"
            style: Text.Outline
            font.family: "Impact"
            anchors.top: parent.top
            anchors.topMargin: 220
            anchors.right: parent.right
            anchors.rightMargin: 30
            anchors.left: parent.left
            anchors.leftMargin: 30

            Component.onCompleted: {
                if (JResolution.getHeight() === "640")
                    anchors.topMargin = 180;
                font.pointSize = bridge.getFontSizeMenu();
            }
        }

        TextField {
            id: txtRemoteServer
            height: 44
            anchors.top: labelRemoteServer.bottom
            anchors.topMargin: 2
            opacity: 1
            anchors.left: parent.left
            anchors.leftMargin: 30
            anchors.right: parent.right
            anchors.rightMargin: 30
            smooth: true
            font.pixelSize: 30

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    height = 35;
                    anchors.leftMargin = 25;
                    anchors.rightMargin = 25;
                    font.pixelSize = 25;
                }
            }

            Keys.onReturnPressed: {
                translate.y = 0;
                platformCloseSoftwareInputPanel();
            }
        }

        Text {
            id: labelRemotePort
            height: 30
            text: qsTr("Porta server remoto:")
            color: "#FAF567"
            style: Text.Outline
            font.family: "Impact"
            anchors.top: txtRemoteServer.bottom
            anchors.topMargin: 25
            anchors.right: parent.right
            anchors.rightMargin: 30
            anchors.leftMargin: 30
            anchors.left: parent.left

            Component.onCompleted: font.pointSize = bridge.getFontSizeMenu()
        }

        TextField {
            id: txtRemoteServerPort
            height: 44
            anchors.top: labelRemotePort.bottom
            anchors.topMargin: 2
            smooth: true
            font.pixelSize: 30
            anchors.rightMargin: 30
            anchors.right: parent.right
            anchors.leftMargin: 30
            opacity: 1
            anchors.left: parent.left
            inputMethodHints: Qt.ImhFormattedNumbersOnly

            onActiveFocusChanged: {
                if (activeFocus == true) {
                    if (JResolution.getHeight() === "640")
                        translate.y = -60;
                }
                else
                    translate.y = 0;
            }

            Keys.onReturnPressed: {
                translate.y = 0;
                platformCloseSoftwareInputPanel();
            }

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    height = 35;
                    font.pixelSize = 25;
                    anchors.leftMargin = 25;
                    anchors.rightMargin = 25;
                }
            }
        }

        Text {
            id: labelUsername
            height: 30
            text: qsTr("Username:")
            color: "#FAF567"
            style: Text.Outline
            font.family: "Impact"
            anchors.top: txtRemoteServerPort.bottom
            anchors.topMargin: 25
            anchors.right: parent.right
            anchors.rightMargin: 30
            anchors.leftMargin: 30
            anchors.left: parent.left

            Component.onCompleted: font.pointSize = bridge.getFontSizeMenu()
        }

        TextField {
            id: txtUsername
            x: 9
            height: 44
            text: qsTr("nickname\n")
            anchors.top: labelUsername.bottom
            anchors.topMargin: 2
            smooth: true
            font.pixelSize: 30
            anchors.rightMargin: 30
            anchors.right: parent.right
            anchors.leftMargin: 30
            opacity: 1
            anchors.left: parent.left
            maximumLength: 25

            onActiveFocusChanged: {
                if (activeFocus == true) {
                    if (JResolution.getHeight() === "640")
                        translate.y = -140;
                }
                else
                    translate.y = 0;
            }

            Keys.onReturnPressed: {
                translate.y = 0;
                platformCloseSoftwareInputPanel();
            }

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    height = 35;
                    font.pixelSize = 25;
                    anchors.leftMargin = 25;
                    anchors.rightMargin = 25;
                }
            }
        }

        Text {
            id: labelPassword
            text: qsTr("Password:")
            color: "#FAF567"
            style: Text.Outline
            font.family: "Impact"
            anchors.top: txtUsername.bottom
            anchors.topMargin: 25
            anchors.right: parent.right
            anchors.rightMargin: 30
            anchors.leftMargin: 30
            anchors.left: parent.left

            Component.onCompleted: font.pointSize = bridge.getFontSizeMenu()
        }

        TextField {
            id: txtPassword
            height: 44
            anchors.top: labelPassword.bottom
            anchors.topMargin: 2
            smooth: true
            font.pixelSize: 30
            anchors.rightMargin: 30
            anchors.right: parent.right
            anchors.leftMargin: 30
            anchors.left: parent.left
            maximumLength: 16
            echoMode: TextInput.Password

            onActiveFocusChanged: {
                if (activeFocus == true)
                    if (JResolution.getHeight() === "640")
                        translate.y = -240;
                    else
                        translate.y = -80;
                else
                    translate.y = 0;
            }

            Keys.onReturnPressed: {
                translate.y = 0;
                platformCloseSoftwareInputPanel();
            }

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    height = 35;
                    font.pixelSize = 25;
                    anchors.leftMargin = 25;
                    anchors.rightMargin = 25;
                }
            }
        }

        Text {
            id: linkToSite
            textFormat: Text.RichText
            text: qsTr("Non hai un account? crealo") + " " + "<a style='color:#FAF567;visited:#FAF567' href='" + bridge.getLinkToNewAccount() + "'>" + qsTr("qui") + "</a>"
            color: "#FFFFFF"
            style: Text.Outline
            font.pointSize: bridge.getFontSizeMenu()
            font.family: "Impact"
            anchors.top: txtPassword.bottom
            anchors.topMargin: 20
            anchors.leftMargin: 30
            anchors.left: parent.left

            onLinkActivated: {
                linkSound.play()
                Qt.openUrlExternally(bridge.getLinkToNewAccount())
            }

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.topMargin = 5;
                    font.pointSize = bridge.getFontSizeText() + 2;
                }
            }
        }

        Text {
            id: linkToPrivacy
            textFormat: Text.RichText
            text: qsTr("Informazioni sulla privacy:") + " " + "<a style='color:#FAF567;visited:#FAF567' href='" + bridge.getLinkToPrivacy() + "'>" + qsTr("qui") + "</a>"
            color: "#FFFFFF"
            style: Text.Outline
            font.pointSize: bridge.getFontSizeMenu()
            font.family: "Impact"
            anchors.top: linkToSite.bottom
            anchors.topMargin: 20
            anchors.leftMargin: 30
            anchors.left: parent.left

            onLinkActivated: {
                linkSound.play()
                Qt.openUrlExternally(bridge.getLinkToPrivacy())
            }

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.topMargin = 5;
                    font.pointSize = bridge.getFontSizeText() + 2;
                }
            }
        }

        SoftairButton {
            id: cmdBack
            width: 219
            height: 49
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 20
            caption: qsTr("Indietro")
            onClickButton: pageStack.pop();

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.bottomMargin = 16;
                }
            }
        }

        SoftairButton {
            id: cmdSave
            width: 219
            height: 49
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: 20
            caption: qsTr("Salva")
            onClickButton: bridge.saveSettings(txtUsername.text, txtPassword.text, txtRemoteServer.text, txtRemoteServerPort.text);

            Component.onCompleted: {
                if (JResolution.getHeight() === "640") {
                    anchors.bottomMargin = 16;
                }
            }
        }
    }
}
