// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import QtMultimediaKit 1.1
import "../../js/Resolution.js" as JResolution

Rectangle {
    id: button
    color: "#00000000"
    border.color: "white"
    border.width: 0

    Component.onCompleted: {
        if (JResolution.getWidth() === "360" && JResolution.getHeight() === "640") {
            button.width = 150;
            button.height = 42;
        }
        else if (JResolution.getWidth() === "480" && JResolution.getHeight() === "854") {
            button.width = 200;
            button.height = 55;
        }

    }

    SoundEffect {
        id: clickSound
        source: "../../audio/click.wav"
    }

    property alias textColor: text.color
    property alias caption: text.text
    property alias enableEvents: mouse_area.visible

    signal clickButton;
    signal releaseButton;

    BorderImage {
        id: background
        anchors.fill: parent
        source: "qrc:/images/" + JResolution.getJsDeviceResolution() + "/button.png"
        horizontalTileMode: BorderImage.Repeat
        verticalTileMode: BorderImage.Repeat
        border.left: 64; border.top: 10;
        border.right: 20; border.bottom: 10;

        Component.onCompleted: {
            if (JResolution.getWidth() === "360" && JResolution.getHeight() === "640") {
                border.left = 44; border.top = 10;
                border.right = 20; border.bottom = 10;
            }
        }

        Text {
            id: text

            anchors {
                fill: parent
                rightMargin: 5
                leftMargin: 25
            }
            color: "white"
            style: Text.Outline
            font.family: "Impact"
            anchors.topMargin: 6
            anchors.bottomMargin: 4
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter

            Component.onCompleted: font.pointSize = bridge.getFontSizeMenu()
        }

        MouseArea {
            id: mouse_area
            anchors.fill: parent
            onPressed: button.border.width = 1
            onReleased: {
                button.border.width = 0;
                button.releaseButton();
            }

            onClicked: {
                clickSound.play();
                button.clickButton();
            }
        }
    }
}
