// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import QtMultimediaKit 1.1


Rectangle {
    id: switchButton
    color: "transparent"
    enabled: true
    //
    // impostando a true questa proprieta', viene resettato il pulsante come se non fosse stato premuto
    property bool resetClickStatus: false
    //
    // immagine da posizionare sul pulsante:
    property string foregroundImage: ""
    property alias  foregroundImageWidth: imgButtonForeground.width
    property alias  foregroundImageHeight: imgButtonForeground.height
    //
    // contiene l'immagine di background per il pulsante non premuto
    property string backgroundOff: ""
    //
    // contiene l'immagine di background per il pulsante premuto
    property string backgroundOn: ""
    //
    // eventuale suono da emettere alla pressione del pulsante:
    property string soundClick: ""
    //
    // comportamenti che puo' avere il pulsante (se attivato, non verra' emesso l'evento click):
    property bool pressAndHoldBehavior: false
    //
    // segnali esclusivi emessi dal pulsante:
    signal clickButton
    signal pressAndHoldButton

    onEnabledChanged: {
        if (switchButton.enabled == false)
            switchButton.opacity = 0.4;
        else
            switchButton.opacity = 1.0;
        upperClickableArea.visible = clickableArea.visible = switchButton.enabled;
    }

    onForegroundImageWidthChanged: imgButtonForeground.fillMode = Image.PreserveAspectFit
    onForegroundImageHeightChanged: imgButtonForeground.fillMode = Image.PreserveAspectFit

    onResetClickStatusChanged: {
        if (resetClickStatus == true) {
            imgButtonBackground.source = backgroundOff;
            resetClickStatus = false;
        }
    }

    SoundEffect {
        id:clickSound
        source: soundClick
    }

    MouseArea {
        id: upperClickableArea
        z:10
        anchors.fill: parent
        anchors.bottomMargin: switchButton.height / 2

        onPressAndHold: {
            if (pressAndHoldBehavior == true) {
                if (imgButtonBackground.source == backgroundOn) {
                    imgButtonBackground.source =  backgroundOff;
                    pressAndHoldButton();
                }
            }
        }
    }

    MouseArea {
        id: clickableArea
        z: 10
        anchors.fill: parent
        anchors.topMargin: switchButton.height / 2

        onPressed: {
            if (pressAndHoldBehavior == false) {
                imgButtonBackground.source =  backgroundOn;
            }
        }

        onReleased: {
            if (pressAndHoldBehavior == false) {
                imgButtonBackground.source =  backgroundOff;
                if (soundClick !== "") clickSound.play()
            }
        }

        onClicked: {
            if (pressAndHoldBehavior == false)
                clickButton();
        }

        onPressAndHold: {
            if (pressAndHoldBehavior == true) {
                if (imgButtonBackground.source == backgroundOff) {
                    imgButtonBackground.source = backgroundOn;
                    pressAndHoldButton();
                }
            }
        }
    }

    Image {
        id: imgButtonBackground
        source: backgroundOff
        fillMode: Image.PreserveAspectFit
        anchors.fill: parent
        z:1

        Image {
            id: imgButtonForeground
            z:2
            width: parent.width - 15;
            height: parent.width - 15;
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter

            Component.onCompleted: if (foregroundImage != "") source = foregroundImage;
        }
    }
}
