// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import QtMultimediaKit 1.1
import "../../js/Resolution.js" as JResolution

Rectangle {
    id: toolTip
    radius: 18
    color: "#000000"
    border.color: "#98A78E"
    border.width: 1
    opacity: 0.0
    height: 40
    //
    // visualizza il tooltip:
    function showBallon(tip, image, delay) {
        if (timeoutShown.running || timeoutShown.isHidding) { // se e' in corso una visualizzazione di notifica, inserisce nella coda
            queue.append( { "tip":tip,"image":image,"timeout":delay } );
            return; // la coda verra' controllata quando termina la visualizzazione corrente nell'oggetto Timer
        }
        else { // nessuna notifica in visualizzazione quindi esegue quella correntemente richiesta
            timeoutShown.interval = delay;
            imgInfo.source = image;
            caption.text = tip;
            alertSound.play();
            showAnimation.start()
            timeoutShown.start();
        }
    }

    SequentialAnimation {
        id: hideAnimation

        onStarted: timeoutShown.isHidding = true;

        onCompleted: {
            if (queue.count > 0) { // effettua check nella coda per verificare se c'e' qualche notifica in attesa di essere visualizzata
                var tip = queue.get(0).tip;
                var image = queue.get(0).image;
                var delay = queue.get(0).timeout;

                queue.remove(0); // rimuove l'elemento
                timeoutShown.isHidding = false; // per evitare il loop nella chiamata successiva
                showBallon(tip, image, delay);
            }
            timeoutShown.isHidding = false;
        }
        NumberAnimation { target: toolTip; property: "opacity"; from:1.0; to:0.0; duration: 800; }
    }

    SequentialAnimation {
        id: showAnimation
        NumberAnimation { target: toolTip; property: "opacity"; from:0.0; to:1.0; duration: 600; }
    }

    SoundEffect {
        id: alertSound
        source: "../../audio/notify.wav"
    }
    //
    // usata come coda per le notifiche da visualizzare:
    ListModel { id: queue }

    Image {
        id: imgInfo
        width: 39
        height: 39
        anchors.left: parent.left
        anchors.leftMargin: 10
        anchors.top: parent.top
        anchors.topMargin: 0
        fillMode: Image.PreserveAspectFit
    }

    Text {
        id: caption
        color: "white"
        style: Text.Outline
        font.family: "Impact"
        anchors.left: imgInfo.right
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.top: parent.top
        font.pointSize: bridge.getFontSizeMenu()
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter

        Component.onCompleted: {
            if (JResolution.getHeight() === "640")
                caption.font.pointSize = bridge.getFontSizeText() + 2;
        }
    }

    Timer {
        id: timeoutShown

        property bool isHidding: false; // gestita dalla animazione di opacity

        onTriggered: hideAnimation.start(); // check della coda al termine dell'animazione di opacity
    }
}
