// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1


Rectangle {
    id: container
    width: 90
    height: 23
    clip: true
    color: "transparent"
    visible: false

    property int    idObject: -1 // contiene id dell'oggetto
    property string thumbnail;
    property alias  name: txtObjectName.text
    property alias  description: txtObjectDescs.text
    property bool   target: false
    property string scaleView: container.state
    property alias  activablePOI: mouseArea.enabled

    onVisibleChanged: {
        if (visible == false)
            targetAnimation.stop();
        else if (target == true)
            targetAnimation.start();
    }

    onScaleViewChanged: {
        if (container.state != container.scaleView) // se la nuova visualizzazione non e' mai stata applicata
            container.state = container.scaleView;
    }

    onTargetChanged: {
        if (container.target == true) {
            txtObjectName.color = "red";
            targetAnimation.start()
        }
        else {
            txtObjectName.color = "white";
            targetAnimation.stop()
        }
    }

    onThumbnailChanged: imgThumbnail.source = container.thumbnail
    //
    // l'area di selezione target per default e' disabilitata
    MouseArea {
        id: mouseArea
        anchors.fill: container
        enabled: false
        z: 100

        onPressed: {
            var id = 0;

            if (container.target == false)
                id = container.idObject;
            bridge.openMessageList(id, true);
        }
    }

    Image {
        id: imgContainer
        fillMode: Image.PreserveAspectFit
        anchors.fill: parent
        source: "qrc:/images/ContainerCustomObject.png"

        Component.onCompleted: {
            container.width = 90;
            container.height = 23;
        }

        Image {
            id: imgThumbnail
            x: 69
            y: 2
            width: 19
            height: 19
            fillMode: Image.PreserveAspectFit
        }

        NumberAnimation {
            id: targetAnimation
            target: imgThumbnail;
            from: 1.0
            to: 0.0
            property: "opacity";
            duration: 600;
            loops: Animation.Infinite
            onRunningChanged: if (running == false) targetAnimation.target.opacity = 1.0;
        }
    }

    Text {
        id: txtObjectName
        x: 7
        width: 59
        height: 12
        color: "white"
        clip: true
        anchors.top: parent.top
        anchors.topMargin: 0
        verticalAlignment: Text.AlignVCenter
        font.pixelSize: 13
    }

    Text {
        id: txtObjectDescs
        x: 0
        y: 14
        width: 66
        height: 9
        color: "#FAF567"
        clip: true
        anchors.left: parent.left
        anchors.leftMargin: 2
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 0
        font.pixelSize: 9
        verticalAlignment: Text.AlignVCenter
    }
    states: [
        State {
            name: "x1"
            PropertyChanges {
                target: imgContainer
                anchors.fill: parent
                z: 50
                source: "qrc:/images/ContainerCustomObject.png"
            }

            PropertyChanges {
                target: imgThumbnail
                source: container.thumbnail
            }
            PropertyChanges {
                target: txtObjectDescs
                visible: true
            }
            PropertyChanges {
                target: txtObjectName
                visible: true
            }
        },
        State {
            name: "x2"
            PropertyChanges {
                target: container
                height: 18
                z: 50
            }
            PropertyChanges {
                target: txtObjectName
                x: 9
                y: 5
                width: 59
                height: 9
                anchors.topMargin: 0
                font.pixelSize: 11
                visible: true
            }
            PropertyChanges {
                target: imgThumbnail
                x: 0; y: 0; width: 8; height: 8;
            }

            PropertyChanges {
                target: txtObjectDescs
                anchors.leftMargin: 9
                visible: true
            }

            onCompleted: {
                imgContainer.source = "";
                imgThumbnail.source = "qrc:/images/8x8.png";
            }
        },
        State {
            name: "x3"
            PropertyChanges {
                target: container
                height: 9
                z: 50
            }
            PropertyChanges {
                target: txtObjectName
                x: 9
                y: 5
                width: 59
                height: 9
                anchors.topMargin: 0
                font.pixelSize: 11
                visible: true
            }
            PropertyChanges {
                target: imgThumbnail
                x: 0; y: 0; width: 6; height: 6;
            }

            PropertyChanges {
                target: txtObjectDescs
                visible: false
            }

            onCompleted: {
                imgContainer.source = "";
                imgThumbnail.source = "qrc:/images/6x6.png";
            }
        },
        State {
            name: "onRadar"
            PropertyChanges {
                target: container
                height: 12
                width: 12
            }
            PropertyChanges {
                target: txtObjectName
                visible: false
            }
            PropertyChanges {
                target: imgThumbnail
                x: 0; y: 0; width: 12; height: 12;
            }

            PropertyChanges {
                target: txtObjectDescs
                visible: false
            }

            onCompleted: {
                imgContainer.source = "";
                imgThumbnail.source = "qrc:/images/12x12.png";
            }
        }
    ]
}

