// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1


Rectangle {
    id: container
    width: 90
    height: 10
    clip: true
    color: "transparent"
    visible: false
    state: "x1"

    property int    idPlayer: -1 // contiene id dell'oggetto
    property string scaleView: container.state
    property alias  nickname: txtObjectName.text
    property bool   enemy: false
    property bool   commander: false
    property bool   death: false
    property alias  activableMsg: mouseArea.enabled
    property bool   underAttack: false

    onUnderAttackChanged: {
        if (underAttack == true)
            targetAnimation.start()
    }

    onScaleViewChanged: {
        if (container.state != container.scaleView) // se la nuova visualizzazione non e' mai stata applicata
            container.state = container.scaleView;
    }

    onEnemyChanged: {
        if (enemy == true)
            imgPoint.source = "qrc:/images/r8x8.png";
    }

    onCommanderChanged: {
        if (commander == true)
            txtObjectName.color = "#FAF567";
        else
            txtObjectName.color = "white";
    }

    onDeathChanged: {
        if (container.death == true) {
            mouseArea.visible = false;
            imgPoint.source = "qrc:/images/Cross.png";
            txtObjectName.color = "lightgrey";
        }
    }

    Timer {
        id: stopUnderAttackAnimation
        interval: bridge.getSOSMillisecondTime()
        repeat: false
        onTriggered: targetAnimation.stop()
    }

    //
    // l'area di selezione target per default e' disabilitata
    MouseArea {
        id: mouseArea
        anchors.fill: container
        enabled: false
        z: 100

        onPressed: bridge.openMessageList(idPlayer, false);
    }

    Image {
        id: imgPoint
        width: 8
        height: 8
        anchors.left: parent.left
        anchors.leftMargin: 0
        fillMode: Image.PreserveAspectFit
        source: "qrc:/images/b8x8.png"

        NumberAnimation {
            id: targetAnimation
            target: imgPoint;
            from: 1.0
            to: 0.0
            property: "opacity";
            duration: 400;
            loops: Animation.Infinite

            onStarted: {
                stopUnderAttackAnimation.start();
            }

            onRunningChanged: {
                if (running == false) {
                    targetAnimation.target.opacity = 1.0;
                    container.underAttack = false;
                }
            }
        }

        Component.onCompleted: {
            container.width = 90;
            container.height = 10;
        }
    }

    Text {
        id: txtObjectName
        color: "white"
        text: qsTr("Nome oggetto")
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 0
        anchors.right: parent.right
        anchors.rightMargin: 0
        anchors.left: parent.left
        anchors.leftMargin: 10
        anchors.top: parent.top
        anchors.topMargin: 0
        verticalAlignment: Text.AlignVCenter
        font.pixelSize: 12
    }
    states: [
        State {
            name: "onRadar"

            PropertyChanges {
                target: txtObjectName
                visible: false
            }
            PropertyChanges {
                target: container
                width: 8
                z: 50
            }
        },
        State {
            name: "x1"

            PropertyChanges {
                target: txtObjectName
                visible: true
            }
            PropertyChanges {
                target: container
                width: 90
                z: 50
            }
        }
    ]
}

