import QtQuick 1.1
import com.nokia.meego 1.0
import "../../js/Resolution.js" as JResolution


PageStackWindow {
    id: appWindow
    initialPage: Qt.resolvedUrl("MainPage.qml")
    showStatusBar: false
    showToolBar: false

    Component.onCompleted: {
        bridge.internetConnectionUp.connect(connectionUpNotification);
        bridge.internetConnectionDown.connect(connectionDownNotification);
        bridge.tcpServerConnectionDown.connect(tcpServerConnectionDown);
        bridge.tcpServerConnectionUp.connect(noTcpConnection.hideBallon);
        if (bridge.isTcpServerConnected() === false)
            tcpServerConnectionDown();
    }

    Component.onDestruction: {
        bridge.internetConnectionUp.disconnect(connectionUpNotification);
        bridge.internetConnectionDown.disconnect(connectionDownNotification);
        bridge.tcpServerConnectionDown.disconnect(tcpServerConnectionDown);
        bridge.tcpServerConnectionUp.disconnect(noTcpConnection.hideBallon);
    }
    //
    // funzioni per la visualizzazione di notifiche sulla connettivita' internet:
    function connectionUpNotification() {
        if (bridge.isMapInGame() === false) {
            toolTip.showBallon(qsTr("Internet connection up"), "qrc:/images/480x854/light_internet_on.png", 3500)
            if (bridge.isTcpServerConnected() === false)
                tcpServerConnectionDown();
            else
                noTcpConnection.hideBallon();
        }
    }

    function connectionDownNotification() {
        if (bridge.isMapInGame() === false) {
            toolTip.showBallon(qsTr("Internet connection down"), "qrc:/images/480x854/light_internet_off.png", 3500);
            tcpServerConnectionDown();
        }
    }

    function tcpServerConnectionDown() {
        if (bridge.isMapInGame() === false)
            noTcpConnection.showBallon(qsTr("player non connesso al server"));
    }

    ToolTipBallon {
        id: toolTip
        z: 10
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 40
        anchors.left: parent.left
        anchors.leftMargin: 50
        anchors.right: parent.right
        anchors.rightMargin: 50

        Component.onCompleted: {
            if (JResolution.getHeight() === "640") {
                anchors.leftMargin = 25;
                anchors.rightMargin = 25;
            }
        }
    }

    NoTcpConnection {
        id: noTcpConnection
        z: 20
        anchors.top: parent.top
        anchors.topMargin: 5
        anchors.left: parent.left
        anchors.leftMargin: 10
        anchors.right: parent.right
        anchors.rightMargin: 10
    }
}
